# Copyright 2016 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import sys
from antlr3 import *
from antlr3.compat import set, frozenset


# for convenience in actions
HIDDEN = BaseRecognizer.HIDDEN

# token types
MONTH=27
THURSDAY=23
FOURTH_OR_FIFTH=16
THIRD=13
DECEMBER=39
FROM=41
EVERY=6
WEDNESDAY=22
QUARTER=40
SATURDAY=25
SYNCHRONIZED=9
JANUARY=28
SUNDAY=26
TUESDAY=21
SEPTEMBER=36
UNKNOWN_TOKEN=45
AUGUST=35
JULY=34
MAY=32
FRIDAY=24
DIGITS=8
FEBRUARY=29
TWO_DIGIT_HOUR_TIME=43
OF=4
WS=44
EOF=-1
APRIL=31
COMMA=10
JUNE=33
OCTOBER=37
TIME=5
FIFTH=15
NOVEMBER=38
FIRST=11
DIGIT=7
FOURTH=14
MONDAY=20
HOURS=17
MARCH=30
SECOND=12
MINUTES=18
TO=42
DAY=19


class GrocLexer(Lexer):

    grammarFileName = "borg/borgcron/py/Groc.g"
    antlr_version = version_str_to_tuple("3.1.1")
    antlr_version_str = "3.1.1"

    def __init__(self, input=None, state=None):
        if state is None:
            state = RecognizerSharedState()
        Lexer.__init__(self, input, state)

        self.dfa26 = self.DFA26(
            self, 26,
            eot = self.DFA26_eot,
            eof = self.DFA26_eof,
            min = self.DFA26_min,
            max = self.DFA26_max,
            accept = self.DFA26_accept,
            special = self.DFA26_special,
            transition = self.DFA26_transition
            )






    # $ANTLR start "TIME"
    def mTIME(self, ):

        try:
            _type = TIME
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:228:11: ( ( DIGIT ':' '0' .. '5' DIGIT ) )
            # borg/borgcron/py/Groc.g:228:13: ( DIGIT ':' '0' .. '5' DIGIT )
            pass 
            # borg/borgcron/py/Groc.g:228:13: ( DIGIT ':' '0' .. '5' DIGIT )
            # borg/borgcron/py/Groc.g:228:15: DIGIT ':' '0' .. '5' DIGIT
            pass 
            self.mDIGIT()
            self.match(58)
            self.matchRange(48, 53)
            self.mDIGIT()






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "TIME"



    # $ANTLR start "TWO_DIGIT_HOUR_TIME"
    def mTWO_DIGIT_HOUR_TIME(self, ):

        try:
            _type = TWO_DIGIT_HOUR_TIME
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:230:11: ( ( ( ( '0' DIGIT ) | ( '1' DIGIT ) | ( '2' '0' .. '3' ) ) ':' ( '0' .. '5' DIGIT ) ) )
            # borg/borgcron/py/Groc.g:230:13: ( ( ( '0' DIGIT ) | ( '1' DIGIT ) | ( '2' '0' .. '3' ) ) ':' ( '0' .. '5' DIGIT ) )
            pass 
            # borg/borgcron/py/Groc.g:230:13: ( ( ( '0' DIGIT ) | ( '1' DIGIT ) | ( '2' '0' .. '3' ) ) ':' ( '0' .. '5' DIGIT ) )
            # borg/borgcron/py/Groc.g:230:15: ( ( '0' DIGIT ) | ( '1' DIGIT ) | ( '2' '0' .. '3' ) ) ':' ( '0' .. '5' DIGIT )
            pass 
            # borg/borgcron/py/Groc.g:230:15: ( ( '0' DIGIT ) | ( '1' DIGIT ) | ( '2' '0' .. '3' ) )
            alt1 = 3
            LA1 = self.input.LA(1)
            if LA1 == 48:
                alt1 = 1
            elif LA1 == 49:
                alt1 = 2
            elif LA1 == 50:
                alt1 = 3
            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                nvae = NoViableAltException("", 1, 0, self.input)

                raise nvae

            if alt1 == 1:
                # borg/borgcron/py/Groc.g:230:17: ( '0' DIGIT )
                pass 
                # borg/borgcron/py/Groc.g:230:17: ( '0' DIGIT )
                # borg/borgcron/py/Groc.g:230:19: '0' DIGIT
                pass 
                self.match(48)
                self.mDIGIT()





            elif alt1 == 2:
                # borg/borgcron/py/Groc.g:230:33: ( '1' DIGIT )
                pass 
                # borg/borgcron/py/Groc.g:230:33: ( '1' DIGIT )
                # borg/borgcron/py/Groc.g:230:34: '1' DIGIT
                pass 
                self.match(49)
                self.mDIGIT()





            elif alt1 == 3:
                # borg/borgcron/py/Groc.g:230:47: ( '2' '0' .. '3' )
                pass 
                # borg/borgcron/py/Groc.g:230:47: ( '2' '0' .. '3' )
                # borg/borgcron/py/Groc.g:230:48: '2' '0' .. '3'
                pass 
                self.match(50)
                self.matchRange(48, 51)






            self.match(58)
            # borg/borgcron/py/Groc.g:232:15: ( '0' .. '5' DIGIT )
            # borg/borgcron/py/Groc.g:232:17: '0' .. '5' DIGIT
            pass 
            self.matchRange(48, 53)
            self.mDIGIT()



            if self._state.backtracking == 0:
                _type = TIME; 







            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "TWO_DIGIT_HOUR_TIME"



    # $ANTLR start "SYNCHRONIZED"
    def mSYNCHRONIZED(self, ):

        try:
            _type = SYNCHRONIZED
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:234:14: ( 'synchronized' )
            # borg/borgcron/py/Groc.g:234:16: 'synchronized'
            pass 
            self.match("synchronized")



            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "SYNCHRONIZED"



    # $ANTLR start "FIRST"
    def mFIRST(self, ):

        try:
            _type = FIRST
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:237:11: ( ( '1st' | 'first' ) )
            # borg/borgcron/py/Groc.g:237:13: ( '1st' | 'first' )
            pass 
            # borg/borgcron/py/Groc.g:237:13: ( '1st' | 'first' )
            alt2 = 2
            LA2_0 = self.input.LA(1)

            if (LA2_0 == 49) :
                alt2 = 1
            elif (LA2_0 == 102) :
                alt2 = 2
            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                nvae = NoViableAltException("", 2, 0, self.input)

                raise nvae

            if alt2 == 1:
                # borg/borgcron/py/Groc.g:237:15: '1st'
                pass 
                self.match("1st")


            elif alt2 == 2:
                # borg/borgcron/py/Groc.g:237:23: 'first'
                pass 
                self.match("first")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "FIRST"



    # $ANTLR start "SECOND"
    def mSECOND(self, ):

        try:
            _type = SECOND
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:238:11: ( ( '2nd' | 'second' ) )
            # borg/borgcron/py/Groc.g:238:13: ( '2nd' | 'second' )
            pass 
            # borg/borgcron/py/Groc.g:238:13: ( '2nd' | 'second' )
            alt3 = 2
            LA3_0 = self.input.LA(1)

            if (LA3_0 == 50) :
                alt3 = 1
            elif (LA3_0 == 115) :
                alt3 = 2
            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                nvae = NoViableAltException("", 3, 0, self.input)

                raise nvae

            if alt3 == 1:
                # borg/borgcron/py/Groc.g:238:15: '2nd'
                pass 
                self.match("2nd")


            elif alt3 == 2:
                # borg/borgcron/py/Groc.g:238:23: 'second'
                pass 
                self.match("second")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "SECOND"



    # $ANTLR start "THIRD"
    def mTHIRD(self, ):

        try:
            _type = THIRD
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:239:11: ( ( '3rd' | 'third' ) )
            # borg/borgcron/py/Groc.g:239:13: ( '3rd' | 'third' )
            pass 
            # borg/borgcron/py/Groc.g:239:13: ( '3rd' | 'third' )
            alt4 = 2
            LA4_0 = self.input.LA(1)

            if (LA4_0 == 51) :
                alt4 = 1
            elif (LA4_0 == 116) :
                alt4 = 2
            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                nvae = NoViableAltException("", 4, 0, self.input)

                raise nvae

            if alt4 == 1:
                # borg/borgcron/py/Groc.g:239:15: '3rd'
                pass 
                self.match("3rd")


            elif alt4 == 2:
                # borg/borgcron/py/Groc.g:239:23: 'third'
                pass 
                self.match("third")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "THIRD"



    # $ANTLR start "FOURTH"
    def mFOURTH(self, ):

        try:
            _type = FOURTH
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:240:11: ( ( '4th' ) )
            # borg/borgcron/py/Groc.g:240:13: ( '4th' )
            pass 
            # borg/borgcron/py/Groc.g:240:13: ( '4th' )
            # borg/borgcron/py/Groc.g:240:15: '4th'
            pass 
            self.match("4th")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "FOURTH"



    # $ANTLR start "FIFTH"
    def mFIFTH(self, ):

        try:
            _type = FIFTH
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:241:11: ( ( '5th' ) )
            # borg/borgcron/py/Groc.g:241:13: ( '5th' )
            pass 
            # borg/borgcron/py/Groc.g:241:13: ( '5th' )
            # borg/borgcron/py/Groc.g:241:15: '5th'
            pass 
            self.match("5th")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "FIFTH"



    # $ANTLR start "FOURTH_OR_FIFTH"
    def mFOURTH_OR_FIFTH(self, ):

        try:
            _type = FOURTH_OR_FIFTH
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:248:11: ( ( ( 'fourth' ) | ( 'fifth' ) ) )
            # borg/borgcron/py/Groc.g:248:13: ( ( 'fourth' ) | ( 'fifth' ) )
            pass 
            # borg/borgcron/py/Groc.g:248:13: ( ( 'fourth' ) | ( 'fifth' ) )
            alt5 = 2
            LA5_0 = self.input.LA(1)

            if (LA5_0 == 102) :
                LA5_1 = self.input.LA(2)

                if (LA5_1 == 111) :
                    alt5 = 1
                elif (LA5_1 == 105) :
                    alt5 = 2
                else:
                    if self._state.backtracking > 0:
                        raise BacktrackingFailed

                    nvae = NoViableAltException("", 5, 1, self.input)

                    raise nvae

            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                nvae = NoViableAltException("", 5, 0, self.input)

                raise nvae

            if alt5 == 1:
                # borg/borgcron/py/Groc.g:248:15: ( 'fourth' )
                pass 
                # borg/borgcron/py/Groc.g:248:15: ( 'fourth' )
                # borg/borgcron/py/Groc.g:248:16: 'fourth'
                pass 
                self.match("fourth")
                if self._state.backtracking == 0:
                    _type = FOURTH; 






            elif alt5 == 2:
                # borg/borgcron/py/Groc.g:249:15: ( 'fifth' )
                pass 
                # borg/borgcron/py/Groc.g:249:15: ( 'fifth' )
                # borg/borgcron/py/Groc.g:249:16: 'fifth'
                pass 
                self.match("fifth")
                if self._state.backtracking == 0:
                    _type = FIFTH; 










            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "FOURTH_OR_FIFTH"



    # $ANTLR start "DAY"
    def mDAY(self, ):

        try:
            _type = DAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:252:8: ( 'day' )
            # borg/borgcron/py/Groc.g:252:10: 'day'
            pass 
            self.match("day")



            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "DAY"



    # $ANTLR start "MONDAY"
    def mMONDAY(self, ):

        try:
            _type = MONDAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:254:11: ( 'mon' ( 'day' )? )
            # borg/borgcron/py/Groc.g:254:13: 'mon' ( 'day' )?
            pass 
            self.match("mon")
            # borg/borgcron/py/Groc.g:254:19: ( 'day' )?
            alt6 = 2
            LA6_0 = self.input.LA(1)

            if (LA6_0 == 100) :
                alt6 = 1
            if alt6 == 1:
                # borg/borgcron/py/Groc.g:254:20: 'day'
                pass 
                self.match("day")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "MONDAY"



    # $ANTLR start "TUESDAY"
    def mTUESDAY(self, ):

        try:
            _type = TUESDAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:255:11: ( 'tue' ( 'sday' )? )
            # borg/borgcron/py/Groc.g:255:13: 'tue' ( 'sday' )?
            pass 
            self.match("tue")
            # borg/borgcron/py/Groc.g:255:19: ( 'sday' )?
            alt7 = 2
            LA7_0 = self.input.LA(1)

            if (LA7_0 == 115) :
                alt7 = 1
            if alt7 == 1:
                # borg/borgcron/py/Groc.g:255:20: 'sday'
                pass 
                self.match("sday")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "TUESDAY"



    # $ANTLR start "WEDNESDAY"
    def mWEDNESDAY(self, ):

        try:
            _type = WEDNESDAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:256:11: ( 'wed' ( 'nesday' )? )
            # borg/borgcron/py/Groc.g:256:13: 'wed' ( 'nesday' )?
            pass 
            self.match("wed")
            # borg/borgcron/py/Groc.g:256:19: ( 'nesday' )?
            alt8 = 2
            LA8_0 = self.input.LA(1)

            if (LA8_0 == 110) :
                alt8 = 1
            if alt8 == 1:
                # borg/borgcron/py/Groc.g:256:20: 'nesday'
                pass 
                self.match("nesday")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "WEDNESDAY"



    # $ANTLR start "THURSDAY"
    def mTHURSDAY(self, ):

        try:
            _type = THURSDAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:257:11: ( 'thu' ( 'rsday' )? )
            # borg/borgcron/py/Groc.g:257:13: 'thu' ( 'rsday' )?
            pass 
            self.match("thu")
            # borg/borgcron/py/Groc.g:257:19: ( 'rsday' )?
            alt9 = 2
            LA9_0 = self.input.LA(1)

            if (LA9_0 == 114) :
                alt9 = 1
            if alt9 == 1:
                # borg/borgcron/py/Groc.g:257:20: 'rsday'
                pass 
                self.match("rsday")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "THURSDAY"



    # $ANTLR start "FRIDAY"
    def mFRIDAY(self, ):

        try:
            _type = FRIDAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:258:11: ( 'fri' ( 'day' )? )
            # borg/borgcron/py/Groc.g:258:13: 'fri' ( 'day' )?
            pass 
            self.match("fri")
            # borg/borgcron/py/Groc.g:258:19: ( 'day' )?
            alt10 = 2
            LA10_0 = self.input.LA(1)

            if (LA10_0 == 100) :
                alt10 = 1
            if alt10 == 1:
                # borg/borgcron/py/Groc.g:258:20: 'day'
                pass 
                self.match("day")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "FRIDAY"



    # $ANTLR start "SATURDAY"
    def mSATURDAY(self, ):

        try:
            _type = SATURDAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:259:11: ( 'sat' ( 'urday' )? )
            # borg/borgcron/py/Groc.g:259:13: 'sat' ( 'urday' )?
            pass 
            self.match("sat")
            # borg/borgcron/py/Groc.g:259:19: ( 'urday' )?
            alt11 = 2
            LA11_0 = self.input.LA(1)

            if (LA11_0 == 117) :
                alt11 = 1
            if alt11 == 1:
                # borg/borgcron/py/Groc.g:259:20: 'urday'
                pass 
                self.match("urday")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "SATURDAY"



    # $ANTLR start "SUNDAY"
    def mSUNDAY(self, ):

        try:
            _type = SUNDAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:260:11: ( 'sun' ( 'day' )? )
            # borg/borgcron/py/Groc.g:260:13: 'sun' ( 'day' )?
            pass 
            self.match("sun")
            # borg/borgcron/py/Groc.g:260:19: ( 'day' )?
            alt12 = 2
            LA12_0 = self.input.LA(1)

            if (LA12_0 == 100) :
                alt12 = 1
            if alt12 == 1:
                # borg/borgcron/py/Groc.g:260:20: 'day'
                pass 
                self.match("day")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "SUNDAY"



    # $ANTLR start "JANUARY"
    def mJANUARY(self, ):

        try:
            _type = JANUARY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:263:11: ( 'jan' ( 'uary' )? )
            # borg/borgcron/py/Groc.g:263:13: 'jan' ( 'uary' )?
            pass 
            self.match("jan")
            # borg/borgcron/py/Groc.g:263:19: ( 'uary' )?
            alt13 = 2
            LA13_0 = self.input.LA(1)

            if (LA13_0 == 117) :
                alt13 = 1
            if alt13 == 1:
                # borg/borgcron/py/Groc.g:263:20: 'uary'
                pass 
                self.match("uary")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "JANUARY"



    # $ANTLR start "FEBRUARY"
    def mFEBRUARY(self, ):

        try:
            _type = FEBRUARY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:264:11: ( 'feb' ( 'ruary' )? )
            # borg/borgcron/py/Groc.g:264:13: 'feb' ( 'ruary' )?
            pass 
            self.match("feb")
            # borg/borgcron/py/Groc.g:264:19: ( 'ruary' )?
            alt14 = 2
            LA14_0 = self.input.LA(1)

            if (LA14_0 == 114) :
                alt14 = 1
            if alt14 == 1:
                # borg/borgcron/py/Groc.g:264:20: 'ruary'
                pass 
                self.match("ruary")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "FEBRUARY"



    # $ANTLR start "MARCH"
    def mMARCH(self, ):

        try:
            _type = MARCH
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:265:11: ( 'mar' ( 'ch' )? )
            # borg/borgcron/py/Groc.g:265:13: 'mar' ( 'ch' )?
            pass 
            self.match("mar")
            # borg/borgcron/py/Groc.g:265:19: ( 'ch' )?
            alt15 = 2
            LA15_0 = self.input.LA(1)

            if (LA15_0 == 99) :
                alt15 = 1
            if alt15 == 1:
                # borg/borgcron/py/Groc.g:265:20: 'ch'
                pass 
                self.match("ch")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "MARCH"



    # $ANTLR start "APRIL"
    def mAPRIL(self, ):

        try:
            _type = APRIL
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:266:11: ( 'apr' ( 'il' )? )
            # borg/borgcron/py/Groc.g:266:13: 'apr' ( 'il' )?
            pass 
            self.match("apr")
            # borg/borgcron/py/Groc.g:266:19: ( 'il' )?
            alt16 = 2
            LA16_0 = self.input.LA(1)

            if (LA16_0 == 105) :
                alt16 = 1
            if alt16 == 1:
                # borg/borgcron/py/Groc.g:266:20: 'il'
                pass 
                self.match("il")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "APRIL"



    # $ANTLR start "MAY"
    def mMAY(self, ):

        try:
            _type = MAY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:267:11: ( 'may' )
            # borg/borgcron/py/Groc.g:267:13: 'may'
            pass 
            self.match("may")



            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "MAY"



    # $ANTLR start "JUNE"
    def mJUNE(self, ):

        try:
            _type = JUNE
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:268:11: ( 'jun' ( 'e' )? )
            # borg/borgcron/py/Groc.g:268:13: 'jun' ( 'e' )?
            pass 
            self.match("jun")
            # borg/borgcron/py/Groc.g:268:19: ( 'e' )?
            alt17 = 2
            LA17_0 = self.input.LA(1)

            if (LA17_0 == 101) :
                alt17 = 1
            if alt17 == 1:
                # borg/borgcron/py/Groc.g:268:20: 'e'
                pass 
                self.match(101)






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "JUNE"



    # $ANTLR start "JULY"
    def mJULY(self, ):

        try:
            _type = JULY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:269:11: ( 'jul' ( 'y' )? )
            # borg/borgcron/py/Groc.g:269:13: 'jul' ( 'y' )?
            pass 
            self.match("jul")
            # borg/borgcron/py/Groc.g:269:19: ( 'y' )?
            alt18 = 2
            LA18_0 = self.input.LA(1)

            if (LA18_0 == 121) :
                alt18 = 1
            if alt18 == 1:
                # borg/borgcron/py/Groc.g:269:20: 'y'
                pass 
                self.match(121)






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "JULY"



    # $ANTLR start "AUGUST"
    def mAUGUST(self, ):

        try:
            _type = AUGUST
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:270:11: ( 'aug' ( 'ust' )? )
            # borg/borgcron/py/Groc.g:270:13: 'aug' ( 'ust' )?
            pass 
            self.match("aug")
            # borg/borgcron/py/Groc.g:270:19: ( 'ust' )?
            alt19 = 2
            LA19_0 = self.input.LA(1)

            if (LA19_0 == 117) :
                alt19 = 1
            if alt19 == 1:
                # borg/borgcron/py/Groc.g:270:20: 'ust'
                pass 
                self.match("ust")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "AUGUST"



    # $ANTLR start "SEPTEMBER"
    def mSEPTEMBER(self, ):

        try:
            _type = SEPTEMBER
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:271:11: ( 'sep' ( 'tember' )? )
            # borg/borgcron/py/Groc.g:271:13: 'sep' ( 'tember' )?
            pass 
            self.match("sep")
            # borg/borgcron/py/Groc.g:271:19: ( 'tember' )?
            alt20 = 2
            LA20_0 = self.input.LA(1)

            if (LA20_0 == 116) :
                alt20 = 1
            if alt20 == 1:
                # borg/borgcron/py/Groc.g:271:20: 'tember'
                pass 
                self.match("tember")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "SEPTEMBER"



    # $ANTLR start "OCTOBER"
    def mOCTOBER(self, ):

        try:
            _type = OCTOBER
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:272:11: ( 'oct' ( 'ober' )? )
            # borg/borgcron/py/Groc.g:272:13: 'oct' ( 'ober' )?
            pass 
            self.match("oct")
            # borg/borgcron/py/Groc.g:272:19: ( 'ober' )?
            alt21 = 2
            LA21_0 = self.input.LA(1)

            if (LA21_0 == 111) :
                alt21 = 1
            if alt21 == 1:
                # borg/borgcron/py/Groc.g:272:20: 'ober'
                pass 
                self.match("ober")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "OCTOBER"



    # $ANTLR start "NOVEMBER"
    def mNOVEMBER(self, ):

        try:
            _type = NOVEMBER
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:273:11: ( 'nov' ( 'ember' )? )
            # borg/borgcron/py/Groc.g:273:13: 'nov' ( 'ember' )?
            pass 
            self.match("nov")
            # borg/borgcron/py/Groc.g:273:19: ( 'ember' )?
            alt22 = 2
            LA22_0 = self.input.LA(1)

            if (LA22_0 == 101) :
                alt22 = 1
            if alt22 == 1:
                # borg/borgcron/py/Groc.g:273:20: 'ember'
                pass 
                self.match("ember")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "NOVEMBER"



    # $ANTLR start "DECEMBER"
    def mDECEMBER(self, ):

        try:
            _type = DECEMBER
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:274:11: ( 'dec' ( 'ember' )? )
            # borg/borgcron/py/Groc.g:274:13: 'dec' ( 'ember' )?
            pass 
            self.match("dec")
            # borg/borgcron/py/Groc.g:274:19: ( 'ember' )?
            alt23 = 2
            LA23_0 = self.input.LA(1)

            if (LA23_0 == 101) :
                alt23 = 1
            if alt23 == 1:
                # borg/borgcron/py/Groc.g:274:20: 'ember'
                pass 
                self.match("ember")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "DECEMBER"



    # $ANTLR start "MONTH"
    def mMONTH(self, ):

        try:
            _type = MONTH
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:276:11: ( ( 'month' ) )
            # borg/borgcron/py/Groc.g:276:13: ( 'month' )
            pass 
            # borg/borgcron/py/Groc.g:276:13: ( 'month' )
            # borg/borgcron/py/Groc.g:276:15: 'month'
            pass 
            self.match("month")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "MONTH"



    # $ANTLR start "QUARTER"
    def mQUARTER(self, ):

        try:
            _type = QUARTER
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:277:11: ( ( 'quarter' ) )
            # borg/borgcron/py/Groc.g:277:13: ( 'quarter' )
            pass 
            # borg/borgcron/py/Groc.g:277:13: ( 'quarter' )
            # borg/borgcron/py/Groc.g:277:15: 'quarter'
            pass 
            self.match("quarter")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "QUARTER"



    # $ANTLR start "EVERY"
    def mEVERY(self, ):

        try:
            _type = EVERY
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:278:11: ( ( 'every' ) )
            # borg/borgcron/py/Groc.g:278:13: ( 'every' )
            pass 
            # borg/borgcron/py/Groc.g:278:13: ( 'every' )
            # borg/borgcron/py/Groc.g:278:15: 'every'
            pass 
            self.match("every")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "EVERY"



    # $ANTLR start "HOURS"
    def mHOURS(self, ):

        try:
            _type = HOURS
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:280:11: ( ( 'hours' ) )
            # borg/borgcron/py/Groc.g:280:13: ( 'hours' )
            pass 
            # borg/borgcron/py/Groc.g:280:13: ( 'hours' )
            # borg/borgcron/py/Groc.g:280:15: 'hours'
            pass 
            self.match("hours")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "HOURS"



    # $ANTLR start "MINUTES"
    def mMINUTES(self, ):

        try:
            _type = MINUTES
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:281:11: ( ( 'mins' | 'minutes' ) )
            # borg/borgcron/py/Groc.g:281:13: ( 'mins' | 'minutes' )
            pass 
            # borg/borgcron/py/Groc.g:281:13: ( 'mins' | 'minutes' )
            alt24 = 2
            LA24_0 = self.input.LA(1)

            if (LA24_0 == 109) :
                LA24_1 = self.input.LA(2)

                if (LA24_1 == 105) :
                    LA24_2 = self.input.LA(3)

                    if (LA24_2 == 110) :
                        LA24_3 = self.input.LA(4)

                        if (LA24_3 == 115) :
                            alt24 = 1
                        elif (LA24_3 == 117) :
                            alt24 = 2
                        else:
                            if self._state.backtracking > 0:
                                raise BacktrackingFailed

                            nvae = NoViableAltException("", 24, 3, self.input)

                            raise nvae

                    else:
                        if self._state.backtracking > 0:
                            raise BacktrackingFailed

                        nvae = NoViableAltException("", 24, 2, self.input)

                        raise nvae

                else:
                    if self._state.backtracking > 0:
                        raise BacktrackingFailed

                    nvae = NoViableAltException("", 24, 1, self.input)

                    raise nvae

            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                nvae = NoViableAltException("", 24, 0, self.input)

                raise nvae

            if alt24 == 1:
                # borg/borgcron/py/Groc.g:281:15: 'mins'
                pass 
                self.match("mins")


            elif alt24 == 2:
                # borg/borgcron/py/Groc.g:281:24: 'minutes'
                pass 
                self.match("minutes")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "MINUTES"



    # $ANTLR start "COMMA"
    def mCOMMA(self, ):

        try:
            _type = COMMA
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:284:11: ( ( ',' ) )
            # borg/borgcron/py/Groc.g:284:13: ( ',' )
            pass 
            # borg/borgcron/py/Groc.g:284:13: ( ',' )
            # borg/borgcron/py/Groc.g:284:15: ','
            pass 
            self.match(44)






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "COMMA"



    # $ANTLR start "OF"
    def mOF(self, ):

        try:
            _type = OF
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:285:11: ( ( 'of' ) )
            # borg/borgcron/py/Groc.g:285:13: ( 'of' )
            pass 
            # borg/borgcron/py/Groc.g:285:13: ( 'of' )
            # borg/borgcron/py/Groc.g:285:15: 'of'
            pass 
            self.match("of")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "OF"



    # $ANTLR start "FROM"
    def mFROM(self, ):

        try:
            _type = FROM
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:286:11: ( ( 'from' ) )
            # borg/borgcron/py/Groc.g:286:13: ( 'from' )
            pass 
            # borg/borgcron/py/Groc.g:286:13: ( 'from' )
            # borg/borgcron/py/Groc.g:286:15: 'from'
            pass 
            self.match("from")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "FROM"



    # $ANTLR start "TO"
    def mTO(self, ):

        try:
            _type = TO
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:287:11: ( ( 'to' ) )
            # borg/borgcron/py/Groc.g:287:13: ( 'to' )
            pass 
            # borg/borgcron/py/Groc.g:287:13: ( 'to' )
            # borg/borgcron/py/Groc.g:287:15: 'to'
            pass 
            self.match("to")






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "TO"



    # $ANTLR start "WS"
    def mWS(self, ):

        try:
            _type = WS
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:288:11: ( ( ' ' | '\\t' | '\\n' | '\\r' ) )
            # borg/borgcron/py/Groc.g:288:13: ( ' ' | '\\t' | '\\n' | '\\r' )
            pass 
            if (9 <= self.input.LA(1) <= 10) or self.input.LA(1) == 13 or self.input.LA(1) == 32:
                self.input.consume()
            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                mse = MismatchedSetException(None, self.input)
                self.recover(mse)
                raise mse

            if self._state.backtracking == 0:
                _channel=HIDDEN; 




            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "WS"



    # $ANTLR start "DIGIT"
    def mDIGIT(self, ):

        try:
            _type = DIGIT
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:290:11: ( ( '0' .. '9' ) )
            # borg/borgcron/py/Groc.g:290:13: ( '0' .. '9' )
            pass 
            # borg/borgcron/py/Groc.g:290:13: ( '0' .. '9' )
            # borg/borgcron/py/Groc.g:290:15: '0' .. '9'
            pass 
            self.matchRange(48, 57)






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "DIGIT"



    # $ANTLR start "DIGITS"
    def mDIGITS(self, ):

        try:
            _type = DIGITS
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:291:11: ( ( ( DIGIT DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT ) ) )
            # borg/borgcron/py/Groc.g:291:13: ( ( DIGIT DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT ) )
            pass 
            # borg/borgcron/py/Groc.g:291:13: ( ( DIGIT DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT DIGIT ) | ( DIGIT DIGIT ) )
            alt25 = 4
            LA25_0 = self.input.LA(1)

            if ((48 <= LA25_0 <= 57)) :
                LA25_1 = self.input.LA(2)

                if ((48 <= LA25_1 <= 57)) :
                    LA25_2 = self.input.LA(3)

                    if ((48 <= LA25_2 <= 57)) :
                        LA25_4 = self.input.LA(4)

                        if ((48 <= LA25_4 <= 57)) :
                            LA25_6 = self.input.LA(5)

                            if ((48 <= LA25_6 <= 57)) and (self.synpred1_Groc()):
                                alt25 = 1
                            else:
                                alt25 = 2
                        else:
                            alt25 = 3
                    else:
                        alt25 = 4
                else:
                    if self._state.backtracking > 0:
                        raise BacktrackingFailed

                    nvae = NoViableAltException("", 25, 1, self.input)

                    raise nvae

            else:
                if self._state.backtracking > 0:
                    raise BacktrackingFailed

                nvae = NoViableAltException("", 25, 0, self.input)

                raise nvae

            if alt25 == 1:
                # borg/borgcron/py/Groc.g:291:15: ( DIGIT DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT DIGIT )
                pass 
                # borg/borgcron/py/Groc.g:291:52: ( DIGIT DIGIT DIGIT DIGIT DIGIT )
                # borg/borgcron/py/Groc.g:291:54: DIGIT DIGIT DIGIT DIGIT DIGIT
                pass 
                self.mDIGIT()
                self.mDIGIT()
                self.mDIGIT()
                self.mDIGIT()
                self.mDIGIT()





            elif alt25 == 2:
                # borg/borgcron/py/Groc.g:292:15: ( DIGIT DIGIT DIGIT DIGIT )=> ( DIGIT DIGIT DIGIT DIGIT )
                pass 
                # borg/borgcron/py/Groc.g:292:46: ( DIGIT DIGIT DIGIT DIGIT )
                # borg/borgcron/py/Groc.g:292:48: DIGIT DIGIT DIGIT DIGIT
                pass 
                self.mDIGIT()
                self.mDIGIT()
                self.mDIGIT()
                self.mDIGIT()





            elif alt25 == 3:
                # borg/borgcron/py/Groc.g:293:15: ( DIGIT DIGIT DIGIT )
                pass 
                # borg/borgcron/py/Groc.g:293:15: ( DIGIT DIGIT DIGIT )
                # borg/borgcron/py/Groc.g:293:17: DIGIT DIGIT DIGIT
                pass 
                self.mDIGIT()
                self.mDIGIT()
                self.mDIGIT()





            elif alt25 == 4:
                # borg/borgcron/py/Groc.g:294:15: ( DIGIT DIGIT )
                pass 
                # borg/borgcron/py/Groc.g:294:15: ( DIGIT DIGIT )
                # borg/borgcron/py/Groc.g:294:17: DIGIT DIGIT
                pass 
                self.mDIGIT()
                self.mDIGIT()









            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "DIGITS"



    # $ANTLR start "UNKNOWN_TOKEN"
    def mUNKNOWN_TOKEN(self, ):

        try:
            _type = UNKNOWN_TOKEN
            _channel = DEFAULT_CHANNEL

            # borg/borgcron/py/Groc.g:299:15: ( ( . ) )
            # borg/borgcron/py/Groc.g:299:17: ( . )
            pass 
            # borg/borgcron/py/Groc.g:299:17: ( . )
            # borg/borgcron/py/Groc.g:299:19: .
            pass 
            self.matchAny()






            self._state.type = _type
            self._state.channel = _channel

        finally:

            pass

    # $ANTLR end "UNKNOWN_TOKEN"



    def mTokens(self):
        # borg/borgcron/py/Groc.g:1:8: ( TIME | TWO_DIGIT_HOUR_TIME | SYNCHRONIZED | FIRST | SECOND | THIRD | FOURTH | FIFTH | FOURTH_OR_FIFTH | DAY | MONDAY | TUESDAY | WEDNESDAY | THURSDAY | FRIDAY | SATURDAY | SUNDAY | JANUARY | FEBRUARY | MARCH | APRIL | MAY | JUNE | JULY | AUGUST | SEPTEMBER | OCTOBER | NOVEMBER | DECEMBER | MONTH | QUARTER | EVERY | HOURS | MINUTES | COMMA | OF | FROM | TO | WS | DIGIT | DIGITS | UNKNOWN_TOKEN )
        alt26 = 42
        alt26 = self.dfa26.predict(self.input)
        if alt26 == 1:
            # borg/borgcron/py/Groc.g:1:10: TIME
            pass 
            self.mTIME()


        elif alt26 == 2:
            # borg/borgcron/py/Groc.g:1:15: TWO_DIGIT_HOUR_TIME
            pass 
            self.mTWO_DIGIT_HOUR_TIME()


        elif alt26 == 3:
            # borg/borgcron/py/Groc.g:1:35: SYNCHRONIZED
            pass 
            self.mSYNCHRONIZED()


        elif alt26 == 4:
            # borg/borgcron/py/Groc.g:1:48: FIRST
            pass 
            self.mFIRST()


        elif alt26 == 5:
            # borg/borgcron/py/Groc.g:1:54: SECOND
            pass 
            self.mSECOND()


        elif alt26 == 6:
            # borg/borgcron/py/Groc.g:1:61: THIRD
            pass 
            self.mTHIRD()


        elif alt26 == 7:
            # borg/borgcron/py/Groc.g:1:67: FOURTH
            pass 
            self.mFOURTH()


        elif alt26 == 8:
            # borg/borgcron/py/Groc.g:1:74: FIFTH
            pass 
            self.mFIFTH()


        elif alt26 == 9:
            # borg/borgcron/py/Groc.g:1:80: FOURTH_OR_FIFTH
            pass 
            self.mFOURTH_OR_FIFTH()


        elif alt26 == 10:
            # borg/borgcron/py/Groc.g:1:96: DAY
            pass 
            self.mDAY()


        elif alt26 == 11:
            # borg/borgcron/py/Groc.g:1:100: MONDAY
            pass 
            self.mMONDAY()


        elif alt26 == 12:
            # borg/borgcron/py/Groc.g:1:107: TUESDAY
            pass 
            self.mTUESDAY()


        elif alt26 == 13:
            # borg/borgcron/py/Groc.g:1:115: WEDNESDAY
            pass 
            self.mWEDNESDAY()


        elif alt26 == 14:
            # borg/borgcron/py/Groc.g:1:125: THURSDAY
            pass 
            self.mTHURSDAY()


        elif alt26 == 15:
            # borg/borgcron/py/Groc.g:1:134: FRIDAY
            pass 
            self.mFRIDAY()


        elif alt26 == 16:
            # borg/borgcron/py/Groc.g:1:141: SATURDAY
            pass 
            self.mSATURDAY()


        elif alt26 == 17:
            # borg/borgcron/py/Groc.g:1:150: SUNDAY
            pass 
            self.mSUNDAY()


        elif alt26 == 18:
            # borg/borgcron/py/Groc.g:1:157: JANUARY
            pass 
            self.mJANUARY()


        elif alt26 == 19:
            # borg/borgcron/py/Groc.g:1:165: FEBRUARY
            pass 
            self.mFEBRUARY()


        elif alt26 == 20:
            # borg/borgcron/py/Groc.g:1:174: MARCH
            pass 
            self.mMARCH()


        elif alt26 == 21:
            # borg/borgcron/py/Groc.g:1:180: APRIL
            pass 
            self.mAPRIL()


        elif alt26 == 22:
            # borg/borgcron/py/Groc.g:1:186: MAY
            pass 
            self.mMAY()


        elif alt26 == 23:
            # borg/borgcron/py/Groc.g:1:190: JUNE
            pass 
            self.mJUNE()


        elif alt26 == 24:
            # borg/borgcron/py/Groc.g:1:195: JULY
            pass 
            self.mJULY()


        elif alt26 == 25:
            # borg/borgcron/py/Groc.g:1:200: AUGUST
            pass 
            self.mAUGUST()


        elif alt26 == 26:
            # borg/borgcron/py/Groc.g:1:207: SEPTEMBER
            pass 
            self.mSEPTEMBER()


        elif alt26 == 27:
            # borg/borgcron/py/Groc.g:1:217: OCTOBER
            pass 
            self.mOCTOBER()


        elif alt26 == 28:
            # borg/borgcron/py/Groc.g:1:225: NOVEMBER
            pass 
            self.mNOVEMBER()


        elif alt26 == 29:
            # borg/borgcron/py/Groc.g:1:234: DECEMBER
            pass 
            self.mDECEMBER()


        elif alt26 == 30:
            # borg/borgcron/py/Groc.g:1:243: MONTH
            pass 
            self.mMONTH()


        elif alt26 == 31:
            # borg/borgcron/py/Groc.g:1:249: QUARTER
            pass 
            self.mQUARTER()


        elif alt26 == 32:
            # borg/borgcron/py/Groc.g:1:257: EVERY
            pass 
            self.mEVERY()


        elif alt26 == 33:
            # borg/borgcron/py/Groc.g:1:263: HOURS
            pass 
            self.mHOURS()


        elif alt26 == 34:
            # borg/borgcron/py/Groc.g:1:269: MINUTES
            pass 
            self.mMINUTES()


        elif alt26 == 35:
            # borg/borgcron/py/Groc.g:1:277: COMMA
            pass 
            self.mCOMMA()


        elif alt26 == 36:
            # borg/borgcron/py/Groc.g:1:283: OF
            pass 
            self.mOF()


        elif alt26 == 37:
            # borg/borgcron/py/Groc.g:1:286: FROM
            pass 
            self.mFROM()


        elif alt26 == 38:
            # borg/borgcron/py/Groc.g:1:291: TO
            pass 
            self.mTO()


        elif alt26 == 39:
            # borg/borgcron/py/Groc.g:1:294: WS
            pass 
            self.mWS()


        elif alt26 == 40:
            # borg/borgcron/py/Groc.g:1:297: DIGIT
            pass 
            self.mDIGIT()


        elif alt26 == 41:
            # borg/borgcron/py/Groc.g:1:303: DIGITS
            pass 
            self.mDIGITS()


        elif alt26 == 42:
            # borg/borgcron/py/Groc.g:1:310: UNKNOWN_TOKEN
            pass 
            self.mUNKNOWN_TOKEN()






    # $ANTLR start "synpred1_Groc"
    def synpred1_Groc_fragment(self, ):
        # borg/borgcron/py/Groc.g:291:15: ( DIGIT DIGIT DIGIT DIGIT DIGIT )
        # borg/borgcron/py/Groc.g:291:17: DIGIT DIGIT DIGIT DIGIT DIGIT
        pass 
        self.mDIGIT()
        self.mDIGIT()
        self.mDIGIT()
        self.mDIGIT()
        self.mDIGIT()


    # $ANTLR end "synpred1_Groc"



    # $ANTLR start "synpred2_Groc"
    def synpred2_Groc_fragment(self, ):
        # borg/borgcron/py/Groc.g:292:15: ( DIGIT DIGIT DIGIT DIGIT )
        # borg/borgcron/py/Groc.g:292:17: DIGIT DIGIT DIGIT DIGIT
        pass 
        self.mDIGIT()
        self.mDIGIT()
        self.mDIGIT()
        self.mDIGIT()


    # $ANTLR end "synpred2_Groc"



    def synpred2_Groc(self):
        self._state.backtracking += 1
        start = self.input.mark()
        try:
            self.synpred2_Groc_fragment()
        except BacktrackingFailed:
            success = False
        else:
            success = True
        self.input.rewind(start)
        self._state.backtracking -= 1
        return success

    def synpred1_Groc(self):
        self._state.backtracking += 1
        start = self.input.mark()
        try:
            self.synpred1_Groc_fragment()
        except BacktrackingFailed:
            success = False
        else:
            success = True
        self.input.rewind(start)
        self._state.backtracking -= 1
        return success



    # lookup tables for DFA #26

    DFA26_eot = DFA.unpack(
        u"\1\uffff\4\30\2\27\1\30\1\27\2\30\12\27\4\uffff\1\37\2\uffff\2"
        u"\37\47\uffff\1\113\6\uffff"
        )

    DFA26_eof = DFA.unpack(
        u"\114\uffff"
        )

    DFA26_min = DFA.unpack(
        u"\1\0\4\60\1\141\1\145\1\60\1\150\2\60\2\141\1\145\1\141\1\160\1"
        u"\143\1\157\1\165\1\166\1\157\4\uffff\1\72\2\uffff\2\72\4\uffff"
        u"\1\143\2\uffff\1\146\1\uffff\1\151\2\uffff\1\151\5\uffff\1\156"
        u"\1\162\3\uffff\1\154\17\uffff\1\164\6\uffff"
        )

    DFA26_max = DFA.unpack(
        u"\1\uffff\1\72\1\163\1\156\1\162\1\171\1\162\1\164\1\165\1\164\1"
        u"\72\1\145\1\157\1\145\2\165\1\146\1\157\1\165\1\166\1\157\4\uffff"
        u"\1\72\2\uffff\2\72\4\uffff\1\160\2\uffff\1\162\1\uffff\1\157\2"
        u"\uffff\1\165\5\uffff\1\156\1\171\3\uffff\1\156\17\uffff\1\164\6"
        u"\uffff"
        )

    DFA26_accept = DFA.unpack(
        u"\25\uffff\1\43\1\47\1\52\1\50\1\uffff\1\1\1\4\2\uffff\1\5\1\51"
        u"\1\6\1\3\1\uffff\1\20\1\21\1\uffff\1\11\1\uffff\1\23\1\7\1\uffff"
        u"\1\14\1\46\1\10\1\12\1\35\2\uffff\1\42\1\15\1\22\1\uffff\1\25\1"
        u"\31\1\33\1\44\1\34\1\37\1\40\1\41\1\43\1\47\1\2\1\32\1\17\1\45"
        u"\1\16\1\uffff\1\24\1\26\1\27\1\30\1\36\1\13"
        )

    DFA26_special = DFA.unpack(
        u"\1\0\113\uffff"
        )

            
    DFA26_transition = [
        DFA.unpack(u"\11\27\2\26\2\27\1\26\22\27\1\26\13\27\1\25\3\27\1\1"
        u"\1\2\1\3\1\4\1\7\1\11\4\12\47\27\1\17\2\27\1\13\1\23\1\6\1\27\1"
        u"\24\1\27\1\16\2\27\1\14\1\21\1\20\1\27\1\22\1\27\1\5\1\10\2\27"
        u"\1\15\uff88\27"),
        DFA.unpack(u"\12\31\1\32"),
        DFA.unpack(u"\12\34\1\32\70\uffff\1\33"),
        DFA.unpack(u"\4\35\6\37\1\32\63\uffff\1\36"),
        DFA.unpack(u"\12\37\1\32\67\uffff\1\40"),
        DFA.unpack(u"\1\43\3\uffff\1\42\17\uffff\1\44\3\uffff\1\41"),
        DFA.unpack(u"\1\50\3\uffff\1\45\5\uffff\1\46\2\uffff\1\47"),
        DFA.unpack(u"\12\37\1\32\71\uffff\1\51"),
        DFA.unpack(u"\1\52\6\uffff\1\54\5\uffff\1\53"),
        DFA.unpack(u"\12\37\1\32\71\uffff\1\55"),
        DFA.unpack(u"\12\37\1\32"),
        DFA.unpack(u"\1\56\3\uffff\1\57"),
        DFA.unpack(u"\1\61\7\uffff\1\62\5\uffff\1\60"),
        DFA.unpack(u"\1\63"),
        DFA.unpack(u"\1\64\23\uffff\1\65"),
        DFA.unpack(u"\1\66\4\uffff\1\67"),
        DFA.unpack(u"\1\70\2\uffff\1\71"),
        DFA.unpack(u"\1\72"),
        DFA.unpack(u"\1\73"),
        DFA.unpack(u"\1\74"),
        DFA.unpack(u"\1\75"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\100"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\100"),
        DFA.unpack(u"\1\100"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\36\14\uffff\1\101"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\46\13\uffff\1\33"),
        DFA.unpack(u""),
        DFA.unpack(u"\1\102\5\uffff\1\103"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\40\13\uffff\1\104"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\105"),
        DFA.unpack(u"\1\106\6\uffff\1\107"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\111\1\uffff\1\110"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"\1\112"),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u""),
        DFA.unpack(u"")
    ]

    # class definition for DFA #26

    class DFA26(DFA):
        def specialStateTransition(self_, s, input):
            # convince pylint that my self_ magic is ok ;)
            # pylint: disable-msg=E0213

            # pretend we are a member of the recognizer
            # thus semantic predicates can be evaluated
            self = self_.recognizer

            _s = s

            if s == 0: 
                LA26_0 = input.LA(1)

                s = -1
                if (LA26_0 == 48):
                    s = 1

                elif (LA26_0 == 49):
                    s = 2

                elif (LA26_0 == 50):
                    s = 3

                elif (LA26_0 == 51):
                    s = 4

                elif (LA26_0 == 115):
                    s = 5

                elif (LA26_0 == 102):
                    s = 6

                elif (LA26_0 == 52):
                    s = 7

                elif (LA26_0 == 116):
                    s = 8

                elif (LA26_0 == 53):
                    s = 9

                elif ((54 <= LA26_0 <= 57)):
                    s = 10

                elif (LA26_0 == 100):
                    s = 11

                elif (LA26_0 == 109):
                    s = 12

                elif (LA26_0 == 119):
                    s = 13

                elif (LA26_0 == 106):
                    s = 14

                elif (LA26_0 == 97):
                    s = 15

                elif (LA26_0 == 111):
                    s = 16

                elif (LA26_0 == 110):
                    s = 17

                elif (LA26_0 == 113):
                    s = 18

                elif (LA26_0 == 101):
                    s = 19

                elif (LA26_0 == 104):
                    s = 20

                elif (LA26_0 == 44):
                    s = 21

                elif ((9 <= LA26_0 <= 10) or LA26_0 == 13 or LA26_0 == 32):
                    s = 22

                elif ((0 <= LA26_0 <= 8) or (11 <= LA26_0 <= 12) or (14 <= LA26_0 <= 31) or (33 <= LA26_0 <= 43) or (45 <= LA26_0 <= 47) or (58 <= LA26_0 <= 96) or (98 <= LA26_0 <= 99) or LA26_0 == 103 or LA26_0 == 105 or (107 <= LA26_0 <= 108) or LA26_0 == 112 or LA26_0 == 114 or (117 <= LA26_0 <= 118) or (120 <= LA26_0 <= 65535)):
                    s = 23

                if s >= 0:
                    return s

            if self._state.backtracking >0:
                raise BacktrackingFailed
            nvae = NoViableAltException(self_.getDescription(), 26, _s, input)
            self_.error(nvae)
            raise nvae
 



def main(argv, stdin=sys.stdin, stdout=sys.stdout, stderr=sys.stderr):
    from antlr3.main import LexerMain
    main = LexerMain(GrocLexer)
    main.stdin = stdin
    main.stdout = stdout
    main.stderr = stderr
    main.execute(argv)


if __name__ == '__main__':
    main(sys.argv)



# -*- coding: utf-8 -*- #
# Copyright 2020 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""'vmware sddc clusters delete' command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.vmware.sddc.clusters import ClustersClient
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.vmware.sddc import flags

DETAILED_HELP = {
    'DESCRIPTION':
        """
          Delete a cluster in a VMware Engine private cloud.
        """,
    'EXAMPLES':
        """
          To delete a cluster called ``my-cluster'' in private cloud
          ``my-privatecloud'' and region ``us-central1'', run:

            $ {command} my-cluster --privatecloud=my-privatecloud --region=us-central1 --project=my-project

          Or:

            $ {command} my-cluster --privatecloud=my-privatecloud

          In the second example, the project and region are taken from gcloud properties core/project and vmware/region.
    """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Delete(base.DeleteCommand):
  """Delete a cluster in a VMware Engine private cloud."""

  @staticmethod
  def Args(parser):
    """Register flags for this command."""
    flags.AddClusterArgToParser(parser)

  def Run(self, args):
    cluster = args.CONCEPTS.cluster.Parse()
    client = ClustersClient()
    operation = client.Delete(cluster)
    return client.WaitForOperation(
        operation,
        'waiting for cluster [{}] to be deleted'.format(cluster),
        is_delete=True)


Delete.detailed_help = DETAILED_HELP



"""Generated message classes for dns version v1.

Configures and serves authoritative DNS records.
"""
# NOTE: This file is autogenerated and should not be edited by hand.

from __future__ import absolute_import

from apitools.base.protorpclite import messages as _messages
from apitools.base.py import encoding


package = 'dns'


class Change(_messages.Message):
  r"""A Change object.

  Enums:
    StatusValueValuesEnum:

  Fields:
    additions: A ResourceRecordSet attribute.
    deletions: A ResourceRecordSet attribute.
    id: A string attribute.
    isServing: A boolean attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#change".
    startTime: A string attribute.
    status: A StatusValueValuesEnum attribute.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""StatusValueValuesEnum enum type.

    Values:
      done: <no description>
      pending: <no description>
    """
    done = 0
    pending = 1

  additions = _messages.MessageField('ResourceRecordSet', 1, repeated=True)
  deletions = _messages.MessageField('ResourceRecordSet', 2, repeated=True)
  id = _messages.StringField(3)
  isServing = _messages.BooleanField(4)
  kind = _messages.StringField(5, default='dns#change')
  startTime = _messages.StringField(6)
  status = _messages.EnumField('StatusValueValuesEnum', 7)


class ChangesListResponse(_messages.Message):
  r"""A ChangesListResponse object.

  Fields:
    changes: A Change attribute.
    header: A ResponseHeader attribute.
    kind: Type of resource.
    nextPageToken: A string attribute.
  """

  changes = _messages.MessageField('Change', 1, repeated=True)
  header = _messages.MessageField('ResponseHeader', 2)
  kind = _messages.StringField(3, default='dns#changesListResponse')
  nextPageToken = _messages.StringField(4)


class DnsChangesCreateRequest(_messages.Message):
  r"""A DnsChangesCreateRequest object.

  Fields:
    change: A Change resource to be passed as the request body.
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    project: A string attribute.
  """

  change = _messages.MessageField('Change', 1)
  clientOperationId = _messages.StringField(2)
  managedZone = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)


class DnsChangesGetRequest(_messages.Message):
  r"""A DnsChangesGetRequest object.

  Fields:
    changeId: A string attribute.
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    project: A string attribute.
  """

  changeId = _messages.StringField(1, required=True)
  clientOperationId = _messages.StringField(2)
  managedZone = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)


class DnsChangesListRequest(_messages.Message):
  r"""A DnsChangesListRequest object.

  Enums:
    SortByValueValuesEnum:

  Fields:
    managedZone: A string attribute.
    maxResults: A integer attribute.
    pageToken: A string attribute.
    project: A string attribute.
    sortBy: A SortByValueValuesEnum attribute.
    sortOrder: A string attribute.
  """

  class SortByValueValuesEnum(_messages.Enum):
    r"""SortByValueValuesEnum enum type.

    Values:
      changeSequence: <no description>
    """
    changeSequence = 0

  managedZone = _messages.StringField(1, required=True)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(3)
  project = _messages.StringField(4, required=True)
  sortBy = _messages.EnumField('SortByValueValuesEnum', 5, default='changeSequence')
  sortOrder = _messages.StringField(6)


class DnsDnsKeysGetRequest(_messages.Message):
  r"""A DnsDnsKeysGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    digestType: A string attribute.
    dnsKeyId: A string attribute.
    managedZone: A string attribute.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  digestType = _messages.StringField(2)
  dnsKeyId = _messages.StringField(3, required=True)
  managedZone = _messages.StringField(4, required=True)
  project = _messages.StringField(5, required=True)


class DnsDnsKeysListRequest(_messages.Message):
  r"""A DnsDnsKeysListRequest object.

  Fields:
    digestType: A string attribute.
    managedZone: A string attribute.
    maxResults: A integer attribute.
    pageToken: A string attribute.
    project: A string attribute.
  """

  digestType = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)


class DnsKey(_messages.Message):
  r"""A DnsKey object.

  Enums:
    AlgorithmValueValuesEnum:
    TypeValueValuesEnum:

  Fields:
    algorithm: A AlgorithmValueValuesEnum attribute.
    creationTime: A string attribute.
    description: A string attribute.
    digests: A DnsKeyDigest attribute.
    id: A string attribute.
    isActive: A boolean attribute.
    keyLength: A integer attribute.
    keyTag: A integer attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#dnsKey".
    publicKey: A string attribute.
    type: A TypeValueValuesEnum attribute.
  """

  class AlgorithmValueValuesEnum(_messages.Enum):
    r"""AlgorithmValueValuesEnum enum type.

    Values:
      ecdsap256sha256: <no description>
      ecdsap384sha384: <no description>
      rsasha1: <no description>
      rsasha256: <no description>
      rsasha512: <no description>
    """
    ecdsap256sha256 = 0
    ecdsap384sha384 = 1
    rsasha1 = 2
    rsasha256 = 3
    rsasha512 = 4

  class TypeValueValuesEnum(_messages.Enum):
    r"""TypeValueValuesEnum enum type.

    Values:
      keySigning: <no description>
      zoneSigning: <no description>
    """
    keySigning = 0
    zoneSigning = 1

  algorithm = _messages.EnumField('AlgorithmValueValuesEnum', 1)
  creationTime = _messages.StringField(2)
  description = _messages.StringField(3)
  digests = _messages.MessageField('DnsKeyDigest', 4, repeated=True)
  id = _messages.StringField(5)
  isActive = _messages.BooleanField(6)
  keyLength = _messages.IntegerField(7, variant=_messages.Variant.UINT32)
  keyTag = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  kind = _messages.StringField(9, default='dns#dnsKey')
  publicKey = _messages.StringField(10)
  type = _messages.EnumField('TypeValueValuesEnum', 11)


class DnsKeyDigest(_messages.Message):
  r"""A DnsKeyDigest object.

  Enums:
    TypeValueValuesEnum:

  Fields:
    digest: A string attribute.
    type: A TypeValueValuesEnum attribute.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""TypeValueValuesEnum enum type.

    Values:
      sha1: <no description>
      sha256: <no description>
      sha384: <no description>
    """
    sha1 = 0
    sha256 = 1
    sha384 = 2

  digest = _messages.StringField(1)
  type = _messages.EnumField('TypeValueValuesEnum', 2)


class DnsKeySpec(_messages.Message):
  r"""A DnsKeySpec object.

  Enums:
    AlgorithmValueValuesEnum:
    KeyTypeValueValuesEnum:

  Fields:
    algorithm: A AlgorithmValueValuesEnum attribute.
    keyLength: A integer attribute.
    keyType: A KeyTypeValueValuesEnum attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#dnsKeySpec".
  """

  class AlgorithmValueValuesEnum(_messages.Enum):
    r"""AlgorithmValueValuesEnum enum type.

    Values:
      ecdsap256sha256: <no description>
      ecdsap384sha384: <no description>
      rsasha1: <no description>
      rsasha256: <no description>
      rsasha512: <no description>
    """
    ecdsap256sha256 = 0
    ecdsap384sha384 = 1
    rsasha1 = 2
    rsasha256 = 3
    rsasha512 = 4

  class KeyTypeValueValuesEnum(_messages.Enum):
    r"""KeyTypeValueValuesEnum enum type.

    Values:
      keySigning: <no description>
      zoneSigning: <no description>
    """
    keySigning = 0
    zoneSigning = 1

  algorithm = _messages.EnumField('AlgorithmValueValuesEnum', 1)
  keyLength = _messages.IntegerField(2, variant=_messages.Variant.UINT32)
  keyType = _messages.EnumField('KeyTypeValueValuesEnum', 3)
  kind = _messages.StringField(4, default='dns#dnsKeySpec')


class DnsKeysListResponse(_messages.Message):
  r"""A DnsKeysListResponse object.

  Fields:
    dnsKeys: A DnsKey attribute.
    header: A ResponseHeader attribute.
    kind: Type of resource.
    nextPageToken: A string attribute.
  """

  dnsKeys = _messages.MessageField('DnsKey', 1, repeated=True)
  header = _messages.MessageField('ResponseHeader', 2)
  kind = _messages.StringField(3, default='dns#dnsKeysListResponse')
  nextPageToken = _messages.StringField(4)


class DnsManagedZoneOperationsGetRequest(_messages.Message):
  r"""A DnsManagedZoneOperationsGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    operation: A string attribute.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  operation = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)


class DnsManagedZoneOperationsListRequest(_messages.Message):
  r"""A DnsManagedZoneOperationsListRequest object.

  Enums:
    SortByValueValuesEnum:

  Fields:
    managedZone: A string attribute.
    maxResults: A integer attribute.
    pageToken: A string attribute.
    project: A string attribute.
    sortBy: A SortByValueValuesEnum attribute.
  """

  class SortByValueValuesEnum(_messages.Enum):
    r"""SortByValueValuesEnum enum type.

    Values:
      id: <no description>
      startTime: <no description>
    """
    id = 0
    startTime = 1

  managedZone = _messages.StringField(1, required=True)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(3)
  project = _messages.StringField(4, required=True)
  sortBy = _messages.EnumField('SortByValueValuesEnum', 5, default='startTime')


class DnsManagedZonesCreateRequest(_messages.Message):
  r"""A DnsManagedZonesCreateRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A ManagedZone resource to be passed as the request body.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.MessageField('ManagedZone', 2)
  project = _messages.StringField(3, required=True)


class DnsManagedZonesDeleteRequest(_messages.Message):
  r"""A DnsManagedZonesDeleteRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)


class DnsManagedZonesDeleteResponse(_messages.Message):
  r"""An empty DnsManagedZonesDelete response."""


class DnsManagedZonesGetRequest(_messages.Message):
  r"""A DnsManagedZonesGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)


class DnsManagedZonesListRequest(_messages.Message):
  r"""A DnsManagedZonesListRequest object.

  Fields:
    dnsName: A string attribute.
    maxResults: A integer attribute.
    pageToken: A string attribute.
    project: A string attribute.
  """

  dnsName = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(3)
  project = _messages.StringField(4, required=True)


class DnsManagedZonesPatchRequest(_messages.Message):
  r"""A DnsManagedZonesPatchRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    managedZoneResource: A ManagedZone resource to be passed as the request
      body.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  managedZoneResource = _messages.MessageField('ManagedZone', 3)
  project = _messages.StringField(4, required=True)


class DnsManagedZonesUpdateRequest(_messages.Message):
  r"""A DnsManagedZonesUpdateRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    managedZoneResource: A ManagedZone resource to be passed as the request
      body.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  managedZoneResource = _messages.MessageField('ManagedZone', 3)
  project = _messages.StringField(4, required=True)


class DnsPoliciesCreateRequest(_messages.Message):
  r"""A DnsPoliciesCreateRequest object.

  Fields:
    clientOperationId: A string attribute.
    policy: A Policy resource to be passed as the request body.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  policy = _messages.MessageField('Policy', 2)
  project = _messages.StringField(3, required=True)


class DnsPoliciesDeleteRequest(_messages.Message):
  r"""A DnsPoliciesDeleteRequest object.

  Fields:
    clientOperationId: A string attribute.
    policy: A string attribute.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  policy = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)


class DnsPoliciesDeleteResponse(_messages.Message):
  r"""An empty DnsPoliciesDelete response."""


class DnsPoliciesGetRequest(_messages.Message):
  r"""A DnsPoliciesGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    policy: A string attribute.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  policy = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)


class DnsPoliciesListRequest(_messages.Message):
  r"""A DnsPoliciesListRequest object.

  Fields:
    maxResults: A integer attribute.
    pageToken: A string attribute.
    project: A string attribute.
  """

  maxResults = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  project = _messages.StringField(3, required=True)


class DnsPoliciesPatchRequest(_messages.Message):
  r"""A DnsPoliciesPatchRequest object.

  Fields:
    clientOperationId: A string attribute.
    policy: A string attribute.
    policyResource: A Policy resource to be passed as the request body.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  policy = _messages.StringField(2, required=True)
  policyResource = _messages.MessageField('Policy', 3)
  project = _messages.StringField(4, required=True)


class DnsPoliciesUpdateRequest(_messages.Message):
  r"""A DnsPoliciesUpdateRequest object.

  Fields:
    clientOperationId: A string attribute.
    policy: A string attribute.
    policyResource: A Policy resource to be passed as the request body.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  policy = _messages.StringField(2, required=True)
  policyResource = _messages.MessageField('Policy', 3)
  project = _messages.StringField(4, required=True)


class DnsProjectsGetRequest(_messages.Message):
  r"""A DnsProjectsGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)


class DnsResourceRecordSetsCreateRequest(_messages.Message):
  r"""A DnsResourceRecordSetsCreateRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    project: A string attribute.
    resourceRecordSet: A ResourceRecordSet resource to be passed as the
      request body.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  resourceRecordSet = _messages.MessageField('ResourceRecordSet', 4)


class DnsResourceRecordSetsDeleteRequest(_messages.Message):
  r"""A DnsResourceRecordSetsDeleteRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    name: A string attribute.
    nameAndType: A string attribute.
    project: A string attribute.
    type: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  name = _messages.StringField(3, required=True)
  nameAndType = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  type = _messages.StringField(6, required=True)


class DnsResourceRecordSetsDeleteResponse(_messages.Message):
  r"""An empty DnsResourceRecordSetsDelete response."""


class DnsResourceRecordSetsGetRequest(_messages.Message):
  r"""A DnsResourceRecordSetsGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    name: A string attribute.
    nameAndType: A string attribute.
    project: A string attribute.
    type: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  name = _messages.StringField(3, required=True)
  nameAndType = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  type = _messages.StringField(6, required=True)


class DnsResourceRecordSetsListRequest(_messages.Message):
  r"""A DnsResourceRecordSetsListRequest object.

  Fields:
    managedZone: A string attribute.
    maxResults: A integer attribute.
    name: A string attribute.
    pageToken: A string attribute.
    project: A string attribute.
    type: A string attribute.
  """

  managedZone = _messages.StringField(1, required=True)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  name = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  type = _messages.StringField(6)


class DnsResourceRecordSetsPatchRequest(_messages.Message):
  r"""A DnsResourceRecordSetsPatchRequest object.

  Fields:
    clientOperationId: A string attribute.
    managedZone: A string attribute.
    name: A string attribute.
    nameAndType: A string attribute.
    project: A string attribute.
    resourceRecordSet: A ResourceRecordSet resource to be passed as the
      request body.
    type: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  managedZone = _messages.StringField(2, required=True)
  name = _messages.StringField(3, required=True)
  nameAndType = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  resourceRecordSet = _messages.MessageField('ResourceRecordSet', 6)
  type = _messages.StringField(7, required=True)


class DnsResponsePoliciesCreateRequest(_messages.Message):
  r"""A DnsResponsePoliciesCreateRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A ResponsePolicy resource to be passed as the request
      body.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.MessageField('ResponsePolicy', 3)


class DnsResponsePoliciesDeleteRequest(_messages.Message):
  r"""A DnsResponsePoliciesDeleteRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)


class DnsResponsePoliciesDeleteResponse(_messages.Message):
  r"""An empty DnsResponsePoliciesDelete response."""


class DnsResponsePoliciesGetRequest(_messages.Message):
  r"""A DnsResponsePoliciesGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)


class DnsResponsePoliciesListRequest(_messages.Message):
  r"""A DnsResponsePoliciesListRequest object.

  Fields:
    maxResults: A integer attribute.
    pageToken: A string attribute.
    project: A string attribute.
  """

  maxResults = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  project = _messages.StringField(3, required=True)


class DnsResponsePoliciesPatchRequest(_messages.Message):
  r"""A DnsResponsePoliciesPatchRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
    responsePolicyResource: A ResponsePolicy resource to be passed as the
      request body.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)
  responsePolicyResource = _messages.MessageField('ResponsePolicy', 4)


class DnsResponsePoliciesUpdateRequest(_messages.Message):
  r"""A DnsResponsePoliciesUpdateRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
    responsePolicyResource: A ResponsePolicy resource to be passed as the
      request body.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)
  responsePolicyResource = _messages.MessageField('ResponsePolicy', 4)


class DnsResponsePolicyRulesCreateRequest(_messages.Message):
  r"""A DnsResponsePolicyRulesCreateRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
    responsePolicyRule: A ResponsePolicyRule resource to be passed as the
      request body.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)
  responsePolicyRule = _messages.MessageField('ResponsePolicyRule', 4)


class DnsResponsePolicyRulesDeleteRequest(_messages.Message):
  r"""A DnsResponsePolicyRulesDeleteRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
    responsePolicyRule: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)
  responsePolicyRule = _messages.StringField(4, required=True)


class DnsResponsePolicyRulesDeleteResponse(_messages.Message):
  r"""An empty DnsResponsePolicyRulesDelete response."""


class DnsResponsePolicyRulesGetRequest(_messages.Message):
  r"""A DnsResponsePolicyRulesGetRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
    responsePolicyRule: A string attribute.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)
  responsePolicyRule = _messages.StringField(4, required=True)


class DnsResponsePolicyRulesListRequest(_messages.Message):
  r"""A DnsResponsePolicyRulesListRequest object.

  Fields:
    maxResults: A integer attribute.
    pageToken: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
  """

  maxResults = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  pageToken = _messages.StringField(2)
  project = _messages.StringField(3, required=True)
  responsePolicy = _messages.StringField(4, required=True)


class DnsResponsePolicyRulesPatchRequest(_messages.Message):
  r"""A DnsResponsePolicyRulesPatchRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
    responsePolicyRule: A string attribute.
    responsePolicyRuleResource: A ResponsePolicyRule resource to be passed as
      the request body.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)
  responsePolicyRule = _messages.StringField(4, required=True)
  responsePolicyRuleResource = _messages.MessageField('ResponsePolicyRule', 5)


class DnsResponsePolicyRulesUpdateRequest(_messages.Message):
  r"""A DnsResponsePolicyRulesUpdateRequest object.

  Fields:
    clientOperationId: A string attribute.
    project: A string attribute.
    responsePolicy: A string attribute.
    responsePolicyRule: A string attribute.
    responsePolicyRuleResource: A ResponsePolicyRule resource to be passed as
      the request body.
  """

  clientOperationId = _messages.StringField(1)
  project = _messages.StringField(2, required=True)
  responsePolicy = _messages.StringField(3, required=True)
  responsePolicyRule = _messages.StringField(4, required=True)
  responsePolicyRuleResource = _messages.MessageField('ResponsePolicyRule', 5)


class ManagedZone(_messages.Message):
  r"""A ManagedZone object.

  Enums:
    VisibilityValueValuesEnum:

  Messages:
    LabelsValue: A LabelsValue object.

  Fields:
    cloudLoggingConfig: A ManagedZoneCloudLoggingConfig attribute.
    creationTime: A string attribute.
    description: A string attribute.
    dnsName: A string attribute.
    dnssecConfig: A ManagedZoneDnsSecConfig attribute.
    forwardingConfig: A ManagedZoneForwardingConfig attribute.
    id: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZone".
    labels: A LabelsValue attribute.
    name: A string attribute.
    nameServerSet: A string attribute.
    nameServers: A string attribute.
    peeringConfig: A ManagedZonePeeringConfig attribute.
    privateVisibilityConfig: A ManagedZonePrivateVisibilityConfig attribute.
    reverseLookupConfig: A ManagedZoneReverseLookupConfig attribute.
    serviceDirectoryConfig: A ManagedZoneServiceDirectoryConfig attribute.
    visibility: A VisibilityValueValuesEnum attribute.
  """

  class VisibilityValueValuesEnum(_messages.Enum):
    r"""VisibilityValueValuesEnum enum type.

    Values:
      private: <no description>
      public: <no description>
    """
    private = 0
    public = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""A LabelsValue object.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  cloudLoggingConfig = _messages.MessageField('ManagedZoneCloudLoggingConfig', 1)
  creationTime = _messages.StringField(2)
  description = _messages.StringField(3)
  dnsName = _messages.StringField(4)
  dnssecConfig = _messages.MessageField('ManagedZoneDnsSecConfig', 5)
  forwardingConfig = _messages.MessageField('ManagedZoneForwardingConfig', 6)
  id = _messages.IntegerField(7, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(8, default='dns#managedZone')
  labels = _messages.MessageField('LabelsValue', 9)
  name = _messages.StringField(10)
  nameServerSet = _messages.StringField(11)
  nameServers = _messages.StringField(12, repeated=True)
  peeringConfig = _messages.MessageField('ManagedZonePeeringConfig', 13)
  privateVisibilityConfig = _messages.MessageField('ManagedZonePrivateVisibilityConfig', 14)
  reverseLookupConfig = _messages.MessageField('ManagedZoneReverseLookupConfig', 15)
  serviceDirectoryConfig = _messages.MessageField('ManagedZoneServiceDirectoryConfig', 16)
  visibility = _messages.EnumField('VisibilityValueValuesEnum', 17)


class ManagedZoneCloudLoggingConfig(_messages.Message):
  r"""A ManagedZoneCloudLoggingConfig object.

  Fields:
    enableLogging: A boolean attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZoneCloudLoggingConfig".
  """

  enableLogging = _messages.BooleanField(1)
  kind = _messages.StringField(2, default='dns#managedZoneCloudLoggingConfig')


class ManagedZoneDnsSecConfig(_messages.Message):
  r"""A ManagedZoneDnsSecConfig object.

  Enums:
    NonExistenceValueValuesEnum:
    StateValueValuesEnum:

  Fields:
    defaultKeySpecs: A DnsKeySpec attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZoneDnsSecConfig".
    nonExistence: A NonExistenceValueValuesEnum attribute.
    state: A StateValueValuesEnum attribute.
  """

  class NonExistenceValueValuesEnum(_messages.Enum):
    r"""NonExistenceValueValuesEnum enum type.

    Values:
      nsec: <no description>
      nsec3: <no description>
    """
    nsec = 0
    nsec3 = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""StateValueValuesEnum enum type.

    Values:
      off: <no description>
      on: <no description>
      transfer: <no description>
    """
    off = 0
    on = 1
    transfer = 2

  defaultKeySpecs = _messages.MessageField('DnsKeySpec', 1, repeated=True)
  kind = _messages.StringField(2, default='dns#managedZoneDnsSecConfig')
  nonExistence = _messages.EnumField('NonExistenceValueValuesEnum', 3)
  state = _messages.EnumField('StateValueValuesEnum', 4)


class ManagedZoneForwardingConfig(_messages.Message):
  r"""A ManagedZoneForwardingConfig object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZoneForwardingConfig".
    targetNameServers: A ManagedZoneForwardingConfigNameServerTarget
      attribute.
  """

  kind = _messages.StringField(1, default='dns#managedZoneForwardingConfig')
  targetNameServers = _messages.MessageField('ManagedZoneForwardingConfigNameServerTarget', 2, repeated=True)


class ManagedZoneForwardingConfigNameServerTarget(_messages.Message):
  r"""A ManagedZoneForwardingConfigNameServerTarget object.

  Enums:
    ForwardingPathValueValuesEnum:

  Fields:
    forwardingPath: A ForwardingPathValueValuesEnum attribute.
    ipv4Address: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZoneForwardingConfigNameServerTarget".
  """

  class ForwardingPathValueValuesEnum(_messages.Enum):
    r"""ForwardingPathValueValuesEnum enum type.

    Values:
      default: <no description>
      private: <no description>
    """
    default = 0
    private = 1

  forwardingPath = _messages.EnumField('ForwardingPathValueValuesEnum', 1)
  ipv4Address = _messages.StringField(2)
  kind = _messages.StringField(3, default='dns#managedZoneForwardingConfigNameServerTarget')


class ManagedZoneOperationsListResponse(_messages.Message):
  r"""A ManagedZoneOperationsListResponse object.

  Fields:
    header: A ResponseHeader attribute.
    kind: Type of resource.
    nextPageToken: A string attribute.
    operations: A Operation attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  kind = _messages.StringField(2, default='dns#managedZoneOperationsListResponse')
  nextPageToken = _messages.StringField(3)
  operations = _messages.MessageField('Operation', 4, repeated=True)


class ManagedZonePeeringConfig(_messages.Message):
  r"""A ManagedZonePeeringConfig object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZonePeeringConfig".
    targetNetwork: A ManagedZonePeeringConfigTargetNetwork attribute.
  """

  kind = _messages.StringField(1, default='dns#managedZonePeeringConfig')
  targetNetwork = _messages.MessageField('ManagedZonePeeringConfigTargetNetwork', 2)


class ManagedZonePeeringConfigTargetNetwork(_messages.Message):
  r"""A ManagedZonePeeringConfigTargetNetwork object.

  Fields:
    deactivateTime: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZonePeeringConfigTargetNetwork".
    networkUrl: A string attribute.
  """

  deactivateTime = _messages.StringField(1)
  kind = _messages.StringField(2, default='dns#managedZonePeeringConfigTargetNetwork')
  networkUrl = _messages.StringField(3)


class ManagedZonePrivateVisibilityConfig(_messages.Message):
  r"""A ManagedZonePrivateVisibilityConfig object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZonePrivateVisibilityConfig".
    networks: A ManagedZonePrivateVisibilityConfigNetwork attribute.
  """

  kind = _messages.StringField(1, default='dns#managedZonePrivateVisibilityConfig')
  networks = _messages.MessageField('ManagedZonePrivateVisibilityConfigNetwork', 2, repeated=True)


class ManagedZonePrivateVisibilityConfigNetwork(_messages.Message):
  r"""A ManagedZonePrivateVisibilityConfigNetwork object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZonePrivateVisibilityConfigNetwork".
    networkUrl: A string attribute.
  """

  kind = _messages.StringField(1, default='dns#managedZonePrivateVisibilityConfigNetwork')
  networkUrl = _messages.StringField(2)


class ManagedZoneReverseLookupConfig(_messages.Message):
  r"""A ManagedZoneReverseLookupConfig object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZoneReverseLookupConfig".
  """

  kind = _messages.StringField(1, default='dns#managedZoneReverseLookupConfig')


class ManagedZoneServiceDirectoryConfig(_messages.Message):
  r"""A ManagedZoneServiceDirectoryConfig object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZoneServiceDirectoryConfig".
    namespace: A ManagedZoneServiceDirectoryConfigNamespace attribute.
  """

  kind = _messages.StringField(1, default='dns#managedZoneServiceDirectoryConfig')
  namespace = _messages.MessageField('ManagedZoneServiceDirectoryConfigNamespace', 2)


class ManagedZoneServiceDirectoryConfigNamespace(_messages.Message):
  r"""A ManagedZoneServiceDirectoryConfigNamespace object.

  Fields:
    deletionTime: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#managedZoneServiceDirectoryConfigNamespace".
    namespaceUrl: A string attribute.
  """

  deletionTime = _messages.StringField(1)
  kind = _messages.StringField(2, default='dns#managedZoneServiceDirectoryConfigNamespace')
  namespaceUrl = _messages.StringField(3)


class ManagedZonesListResponse(_messages.Message):
  r"""A ManagedZonesListResponse object.

  Fields:
    header: A ResponseHeader attribute.
    kind: Type of resource.
    managedZones: A ManagedZone attribute.
    nextPageToken: A string attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  kind = _messages.StringField(2, default='dns#managedZonesListResponse')
  managedZones = _messages.MessageField('ManagedZone', 3, repeated=True)
  nextPageToken = _messages.StringField(4)


class Operation(_messages.Message):
  r"""A Operation object.

  Enums:
    StatusValueValuesEnum:

  Fields:
    dnsKeyContext: A OperationDnsKeyContext attribute.
    id: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#operation".
    startTime: A string attribute.
    status: A StatusValueValuesEnum attribute.
    type: A string attribute.
    user: A string attribute.
    zoneContext: A OperationManagedZoneContext attribute.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""StatusValueValuesEnum enum type.

    Values:
      done: <no description>
      pending: <no description>
    """
    done = 0
    pending = 1

  dnsKeyContext = _messages.MessageField('OperationDnsKeyContext', 1)
  id = _messages.StringField(2)
  kind = _messages.StringField(3, default='dns#operation')
  startTime = _messages.StringField(4)
  status = _messages.EnumField('StatusValueValuesEnum', 5)
  type = _messages.StringField(6)
  user = _messages.StringField(7)
  zoneContext = _messages.MessageField('OperationManagedZoneContext', 8)


class OperationDnsKeyContext(_messages.Message):
  r"""A OperationDnsKeyContext object.

  Fields:
    newValue: A DnsKey attribute.
    oldValue: A DnsKey attribute.
  """

  newValue = _messages.MessageField('DnsKey', 1)
  oldValue = _messages.MessageField('DnsKey', 2)


class OperationManagedZoneContext(_messages.Message):
  r"""A OperationManagedZoneContext object.

  Fields:
    newValue: A ManagedZone attribute.
    oldValue: A ManagedZone attribute.
  """

  newValue = _messages.MessageField('ManagedZone', 1)
  oldValue = _messages.MessageField('ManagedZone', 2)


class PoliciesListResponse(_messages.Message):
  r"""A PoliciesListResponse object.

  Fields:
    header: A ResponseHeader attribute.
    kind: Type of resource.
    nextPageToken: A string attribute.
    policies: A Policy attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  kind = _messages.StringField(2, default='dns#policiesListResponse')
  nextPageToken = _messages.StringField(3)
  policies = _messages.MessageField('Policy', 4, repeated=True)


class PoliciesPatchResponse(_messages.Message):
  r"""A PoliciesPatchResponse object.

  Fields:
    header: A ResponseHeader attribute.
    policy: A Policy attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  policy = _messages.MessageField('Policy', 2)


class PoliciesUpdateResponse(_messages.Message):
  r"""A PoliciesUpdateResponse object.

  Fields:
    header: A ResponseHeader attribute.
    policy: A Policy attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  policy = _messages.MessageField('Policy', 2)


class Policy(_messages.Message):
  r"""A Policy object.

  Fields:
    alternativeNameServerConfig: A PolicyAlternativeNameServerConfig
      attribute.
    description: A string attribute.
    enableInboundForwarding: A boolean attribute.
    enableLogging: A boolean attribute.
    id: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#policy".
    name: A string attribute.
    networks: A PolicyNetwork attribute.
  """

  alternativeNameServerConfig = _messages.MessageField('PolicyAlternativeNameServerConfig', 1)
  description = _messages.StringField(2)
  enableInboundForwarding = _messages.BooleanField(3)
  enableLogging = _messages.BooleanField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default='dns#policy')
  name = _messages.StringField(7)
  networks = _messages.MessageField('PolicyNetwork', 8, repeated=True)


class PolicyAlternativeNameServerConfig(_messages.Message):
  r"""A PolicyAlternativeNameServerConfig object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#policyAlternativeNameServerConfig".
    targetNameServers: A PolicyAlternativeNameServerConfigTargetNameServer
      attribute.
  """

  kind = _messages.StringField(1, default='dns#policyAlternativeNameServerConfig')
  targetNameServers = _messages.MessageField('PolicyAlternativeNameServerConfigTargetNameServer', 2, repeated=True)


class PolicyAlternativeNameServerConfigTargetNameServer(_messages.Message):
  r"""A PolicyAlternativeNameServerConfigTargetNameServer object.

  Enums:
    ForwardingPathValueValuesEnum:

  Fields:
    forwardingPath: A ForwardingPathValueValuesEnum attribute.
    ipv4Address: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#policyAlternativeNameServerConfigTargetNameServer".
  """

  class ForwardingPathValueValuesEnum(_messages.Enum):
    r"""ForwardingPathValueValuesEnum enum type.

    Values:
      default: <no description>
      private: <no description>
    """
    default = 0
    private = 1

  forwardingPath = _messages.EnumField('ForwardingPathValueValuesEnum', 1)
  ipv4Address = _messages.StringField(2)
  kind = _messages.StringField(3, default='dns#policyAlternativeNameServerConfigTargetNameServer')


class PolicyNetwork(_messages.Message):
  r"""A PolicyNetwork object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#policyNetwork".
    networkUrl: A string attribute.
  """

  kind = _messages.StringField(1, default='dns#policyNetwork')
  networkUrl = _messages.StringField(2)


class Project(_messages.Message):
  r"""A Project object.

  Fields:
    id: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#project".
    number: A string attribute.
    quota: A Quota attribute.
  """

  id = _messages.StringField(1)
  kind = _messages.StringField(2, default='dns#project')
  number = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  quota = _messages.MessageField('Quota', 4)


class Quota(_messages.Message):
  r"""A Quota object.

  Fields:
    dnsKeysPerManagedZone: A integer attribute.
    itemsPerRoutingPolicy: A integer attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#quota".
    managedZones: A integer attribute.
    managedZonesPerNetwork: A integer attribute.
    networksPerManagedZone: A integer attribute.
    networksPerPolicy: A integer attribute.
    peeringZonesPerTargetNetwork: A integer attribute.
    policies: A integer attribute.
    resourceRecordsPerRrset: A integer attribute.
    rrsetAdditionsPerChange: A integer attribute.
    rrsetDeletionsPerChange: A integer attribute.
    rrsetsPerManagedZone: A integer attribute.
    targetNameServersPerManagedZone: A integer attribute.
    targetNameServersPerPolicy: A integer attribute.
    totalRrdataSizePerChange: A integer attribute.
    whitelistedKeySpecs: A DnsKeySpec attribute.
  """

  dnsKeysPerManagedZone = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  itemsPerRoutingPolicy = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  kind = _messages.StringField(3, default='dns#quota')
  managedZones = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  managedZonesPerNetwork = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  networksPerManagedZone = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  networksPerPolicy = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  peeringZonesPerTargetNetwork = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  policies = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  resourceRecordsPerRrset = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  rrsetAdditionsPerChange = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  rrsetDeletionsPerChange = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  rrsetsPerManagedZone = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  targetNameServersPerManagedZone = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  targetNameServersPerPolicy = _messages.IntegerField(15, variant=_messages.Variant.INT32)
  totalRrdataSizePerChange = _messages.IntegerField(16, variant=_messages.Variant.INT32)
  whitelistedKeySpecs = _messages.MessageField('DnsKeySpec', 17, repeated=True)


class RRSetRoutingPolicy(_messages.Message):
  r"""A RRSetRoutingPolicy object.

  Fields:
    geo: A RRSetRoutingPolicyGeoPolicy attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#rRSetRoutingPolicy".
    wrr: A RRSetRoutingPolicyWrrPolicy attribute.
  """

  geo = _messages.MessageField('RRSetRoutingPolicyGeoPolicy', 1)
  kind = _messages.StringField(2, default='dns#rRSetRoutingPolicy')
  wrr = _messages.MessageField('RRSetRoutingPolicyWrrPolicy', 3)


class RRSetRoutingPolicyGeoPolicy(_messages.Message):
  r"""A RRSetRoutingPolicyGeoPolicy object.

  Fields:
    items: A RRSetRoutingPolicyGeoPolicyGeoPolicyItem attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#rRSetRoutingPolicyGeoPolicy".
  """

  items = _messages.MessageField('RRSetRoutingPolicyGeoPolicyGeoPolicyItem', 1, repeated=True)
  kind = _messages.StringField(2, default='dns#rRSetRoutingPolicyGeoPolicy')


class RRSetRoutingPolicyGeoPolicyGeoPolicyItem(_messages.Message):
  r"""A RRSetRoutingPolicyGeoPolicyGeoPolicyItem object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#rRSetRoutingPolicyGeoPolicyGeoPolicyItem".
    location: A string attribute.
    rrdatas: A string attribute.
    signatureRrdatas: A string attribute.
  """

  kind = _messages.StringField(1, default='dns#rRSetRoutingPolicyGeoPolicyGeoPolicyItem')
  location = _messages.StringField(2)
  rrdatas = _messages.StringField(3, repeated=True)
  signatureRrdatas = _messages.StringField(4, repeated=True)


class RRSetRoutingPolicyWrrPolicy(_messages.Message):
  r"""A RRSetRoutingPolicyWrrPolicy object.

  Fields:
    items: A RRSetRoutingPolicyWrrPolicyWrrPolicyItem attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#rRSetRoutingPolicyWrrPolicy".
  """

  items = _messages.MessageField('RRSetRoutingPolicyWrrPolicyWrrPolicyItem', 1, repeated=True)
  kind = _messages.StringField(2, default='dns#rRSetRoutingPolicyWrrPolicy')


class RRSetRoutingPolicyWrrPolicyWrrPolicyItem(_messages.Message):
  r"""A RRSetRoutingPolicyWrrPolicyWrrPolicyItem object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#rRSetRoutingPolicyWrrPolicyWrrPolicyItem".
    rrdatas: A string attribute.
    signatureRrdatas: A string attribute.
    weight: A number attribute.
  """

  kind = _messages.StringField(1, default='dns#rRSetRoutingPolicyWrrPolicyWrrPolicyItem')
  rrdatas = _messages.StringField(2, repeated=True)
  signatureRrdatas = _messages.StringField(3, repeated=True)
  weight = _messages.FloatField(4)


class ResourceRecordSet(_messages.Message):
  r"""A ResourceRecordSet object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#resourceRecordSet".
    name: A string attribute.
    routingPolicy: A RRSetRoutingPolicy attribute.
    rrdatas: A string attribute.
    signatureRrdatas: A string attribute.
    ttl: A integer attribute.
    type: A string attribute.
  """

  kind = _messages.StringField(1, default='dns#resourceRecordSet')
  name = _messages.StringField(2)
  routingPolicy = _messages.MessageField('RRSetRoutingPolicy', 3)
  rrdatas = _messages.StringField(4, repeated=True)
  signatureRrdatas = _messages.StringField(5, repeated=True)
  ttl = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  type = _messages.StringField(7)


class ResourceRecordSetsListResponse(_messages.Message):
  r"""A ResourceRecordSetsListResponse object.

  Fields:
    header: A ResponseHeader attribute.
    kind: Type of resource.
    nextPageToken: A string attribute.
    rrsets: A ResourceRecordSet attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  kind = _messages.StringField(2, default='dns#resourceRecordSetsListResponse')
  nextPageToken = _messages.StringField(3)
  rrsets = _messages.MessageField('ResourceRecordSet', 4, repeated=True)


class ResponseHeader(_messages.Message):
  r"""A ResponseHeader object.

  Fields:
    operationId: A string attribute.
  """

  operationId = _messages.StringField(1)


class ResponsePoliciesListResponse(_messages.Message):
  r"""A ResponsePoliciesListResponse object.

  Fields:
    header: A ResponseHeader attribute.
    nextPageToken: A string attribute.
    responsePolicies: A ResponsePolicy attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  nextPageToken = _messages.StringField(2)
  responsePolicies = _messages.MessageField('ResponsePolicy', 3, repeated=True)


class ResponsePoliciesPatchResponse(_messages.Message):
  r"""A ResponsePoliciesPatchResponse object.

  Fields:
    header: A ResponseHeader attribute.
    responsePolicy: A ResponsePolicy attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  responsePolicy = _messages.MessageField('ResponsePolicy', 2)


class ResponsePoliciesUpdateResponse(_messages.Message):
  r"""A ResponsePoliciesUpdateResponse object.

  Fields:
    header: A ResponseHeader attribute.
    responsePolicy: A ResponsePolicy attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  responsePolicy = _messages.MessageField('ResponsePolicy', 2)


class ResponsePolicy(_messages.Message):
  r"""A ResponsePolicy object.

  Fields:
    description: A string attribute.
    id: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#responsePolicy".
    networks: A ResponsePolicyNetwork attribute.
    responsePolicyName: A string attribute.
  """

  description = _messages.StringField(1)
  id = _messages.IntegerField(2)
  kind = _messages.StringField(3, default='dns#responsePolicy')
  networks = _messages.MessageField('ResponsePolicyNetwork', 4, repeated=True)
  responsePolicyName = _messages.StringField(5)


class ResponsePolicyNetwork(_messages.Message):
  r"""A ResponsePolicyNetwork object.

  Fields:
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#responsePolicyNetwork".
    networkUrl: A string attribute.
  """

  kind = _messages.StringField(1, default='dns#responsePolicyNetwork')
  networkUrl = _messages.StringField(2)


class ResponsePolicyRule(_messages.Message):
  r"""A ResponsePolicyRule object.

  Enums:
    BehaviorValueValuesEnum:

  Fields:
    behavior: A BehaviorValueValuesEnum attribute.
    dnsName: A string attribute.
    kind: Identifies what kind of resource this is. Value: the fixed string
      "dns#responsePolicyRule".
    localData: A ResponsePolicyRuleLocalData attribute.
    ruleName: A string attribute.
  """

  class BehaviorValueValuesEnum(_messages.Enum):
    r"""BehaviorValueValuesEnum enum type.

    Values:
      behaviorUnspecified: <no description>
      bypassResponsePolicy: <no description>
    """
    behaviorUnspecified = 0
    bypassResponsePolicy = 1

  behavior = _messages.EnumField('BehaviorValueValuesEnum', 1)
  dnsName = _messages.StringField(2)
  kind = _messages.StringField(3, default='dns#responsePolicyRule')
  localData = _messages.MessageField('ResponsePolicyRuleLocalData', 4)
  ruleName = _messages.StringField(5)


class ResponsePolicyRuleLocalData(_messages.Message):
  r"""A ResponsePolicyRuleLocalData object.

  Fields:
    localDatas: A ResourceRecordSet attribute.
  """

  localDatas = _messages.MessageField('ResourceRecordSet', 1, repeated=True)


class ResponsePolicyRulesListResponse(_messages.Message):
  r"""A ResponsePolicyRulesListResponse object.

  Fields:
    header: A ResponseHeader attribute.
    nextPageToken: A string attribute.
    responsePolicyRules: A ResponsePolicyRule attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  nextPageToken = _messages.StringField(2)
  responsePolicyRules = _messages.MessageField('ResponsePolicyRule', 3, repeated=True)


class ResponsePolicyRulesPatchResponse(_messages.Message):
  r"""A ResponsePolicyRulesPatchResponse object.

  Fields:
    header: A ResponseHeader attribute.
    responsePolicyRule: A ResponsePolicyRule attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  responsePolicyRule = _messages.MessageField('ResponsePolicyRule', 2)


class ResponsePolicyRulesUpdateResponse(_messages.Message):
  r"""A ResponsePolicyRulesUpdateResponse object.

  Fields:
    header: A ResponseHeader attribute.
    responsePolicyRule: A ResponsePolicyRule attribute.
  """

  header = _messages.MessageField('ResponseHeader', 1)
  responsePolicyRule = _messages.MessageField('ResponsePolicyRule', 2)


class StandardQueryParameters(_messages.Message):
  r"""Query parameters accepted by all methods.

  Enums:
    AltValueValuesEnum: Data format for the response.

  Fields:
    alt: Data format for the response.
    fields: Selector specifying which fields to include in a partial response.
    key: API key. Your API key identifies your project and provides you with
      API access, quota, and reports. Required unless you provide an OAuth 2.0
      token.
    oauth_token: OAuth 2.0 token for the current user.
    prettyPrint: Returns response with indentations and line breaks.
    quotaUser: An opaque string that represents a user for quota purposes.
      Must not exceed 40 characters.
    trace: A tracing token of the form "token:<tokenid>" to include in api
      requests.
    userIp: Deprecated. Please use quotaUser instead.
  """

  class AltValueValuesEnum(_messages.Enum):
    r"""Data format for the response.

    Values:
      json: Responses with Content-Type of application/json
    """
    json = 0

  alt = _messages.EnumField('AltValueValuesEnum', 1, default='json')
  fields = _messages.StringField(2)
  key = _messages.StringField(3)
  oauth_token = _messages.StringField(4)
  prettyPrint = _messages.BooleanField(5, default=True)
  quotaUser = _messages.StringField(6)
  trace = _messages.StringField(7)
  userIp = _messages.StringField(8)





# -*- coding: utf-8 -*- #
# Copyright 2020 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for suspending the TPU node and GCE VM combination."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from apitools.base.py.exceptions import HttpConflictError
from apitools.base.py.exceptions import HttpNotFoundError

from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute import flags
from googlecloudsdk.command_lib.compute.tpus import flags as tpus_flags
from googlecloudsdk.command_lib.compute.tpus.execution_groups import util as tpu_utils
from googlecloudsdk.core import log


@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
class Resume(base.Command):
  r"""Creates Google Compute TPU and resumes the VM.

  ## EXAMPLES

  To resume a suspended TPU VM combination, run:

    $ {command} test-execution-group --zone=test-zone --project=test-project \
    --accelerator-type=v2-8 --tf-version=2.4.1

  """

  @classmethod
  def Args(cls, parser):
    flags.AddZoneFlag(parser, resource_type='tpu', operation_type='resume')
    tpus_flags.AddTpuNameArg(parser)
    tpus_flags.GetAcceleratorTypeFlag().AddToParser(parser)
    tpus_flags.AddTfVersionFlagForResume(parser)
    tpus_flags.AddPreemptibleFlag(parser)
    tpus_flags.AddVmOnlyFlag(parser)
    tpus_flags.AddNetworkArgsForResume(parser)

  def Run(self, args):
    tpu_utils.DefaultArgs.ValidateZone(args)

    responses = []
    tpu = tpu_utils.TPUNode(self.ReleaseTrack())
    tpu_operation_ref = None
    instance_operation_ref = None
    if not args.vm_only:
      try:
        tpu_operation_ref = tpu.Create(args.execution_group_name,
                                       args.accelerator_type, args.tf_version,
                                       args.zone, args.preemptible,
                                       args.network)
      except HttpConflictError:
        log.status.Print('TPU Node with name:{} already exists, '
                         'try a different name'.format(
                             args.execution_group_name))
        return responses

    instance = tpu_utils.Instance(self.ReleaseTrack())
    try:
      instance_operation_ref = instance.Start(
          args.execution_group_name, args.zone)
    except HttpNotFoundError:
      log.status.Print('Instance:{} not found, possibly deleted.'.format(
          args.execution_group_name))
      return responses

    if instance_operation_ref:
      instance_start_response = instance.WaitForOperation(
          instance_operation_ref, 'Starting GCE VM')
      responses.append(instance_start_response)

    if tpu_operation_ref:
      responses.append(
          tpu.WaitForOperation(tpu_operation_ref, 'Creating TPU node:{}'.format(
              args.execution_group_name)))

    return responses





# -*- coding: utf-8 -*- #
# Copyright 2015 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Resource definitions for cloud platform apis."""

import enum


BASE_URL = 'https://mediaasset.googleapis.com/v1alpha/'
DOCS_URL = 'go/cloud-media-asset'


class Collections(enum.Enum):
  """Collections for all supported apis."""

  PROJECTS = (
      'projects',
      'projects/{projectsId}',
      {},
      ['projectsId'],
      True
  )
  PROJECTS_LOCATIONS = (
      'projects.locations',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_ASSETTYPES = (
      'projects.locations.assetTypes',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/assetTypes/'
              '{assetTypesId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_ASSETTYPES_ASSETS = (
      'projects.locations.assetTypes.assets',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/assetTypes/'
              '{assetTypesId}/assets/{assetsId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_ASSETTYPES_ASSETS_ACTIONS = (
      'projects.locations.assetTypes.assets.actions',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/assetTypes/'
              '{assetTypesId}/assets/{assetsId}/actions/{actionsId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_ASSETTYPES_ASSETS_ANNOTATIONSETS = (
      'projects.locations.assetTypes.assets.annotationSets',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/assetTypes/'
              '{assetTypesId}/assets/{assetsId}/annotationSets/'
              '{annotationSetsId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_ASSETTYPES_ASSETS_ANNOTATIONSETS_ANNOTATIONS = (
      'projects.locations.assetTypes.assets.annotationSets.annotations',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/assetTypes/'
              '{assetTypesId}/assets/{assetsId}/annotationSets/'
              '{annotationSetsId}/annotations/{annotationsId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_ASSETTYPES_RULES = (
      'projects.locations.assetTypes.rules',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/assetTypes/'
              '{assetTypesId}/rules/{rulesId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_CATALOGS = (
      'projects.locations.catalogs',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/catalogs/'
              '{catalogsId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_COMPLEXTYPES = (
      'projects.locations.complexTypes',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/complexTypes/'
              '{complexTypesId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_MODULES = (
      'projects.locations.modules',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/modules/'
              '{modulesId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_OPERATIONS = (
      'projects.locations.operations',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/operations/'
              '{operationsId}',
      },
      ['name'],
      True
  )
  PROJECTS_LOCATIONS_TRANSFORMERS = (
      'projects.locations.transformers',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/transformers/'
              '{transformersId}',
      },
      ['name'],
      True
  )

  def __init__(self, collection_name, path, flat_paths, params,
               enable_uri_parsing):
    self.collection_name = collection_name
    self.path = path
    self.flat_paths = flat_paths
    self.params = params
    self.enable_uri_parsing = enable_uri_parsing



# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Apply a KRM configuration to a Google Cloud Platform resource filename or stdin."""
from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.util.declarative import flags as declarative_flags
from googlecloudsdk.command_lib.util.declarative.clients import kcc_client
from googlecloudsdk.core.console import progress_tracker

_DETAILED_HELP = {
    'EXAMPLES':
        """
      To create or update the resource in file 'my-resource.yaml' in the current project run:
        $ {command} my-resource.yaml
    """
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Apply(base.DeclarativeCommand):
  """Apply a KRM configuration to a Google Cloud Platform resource filename or stdin."""
  detailed_help = _DETAILED_HELP

  @classmethod
  def Args(cls, parser):
    declarative_flags.AddResolveResourcesArg(parser)
    declarative_flags.AddApplyPathArg(parser)
    parser.display_info.AddFormat('yaml')

  def Run(self, args):
    resource_path = args.PATH
    resolve_refs = args.resolve_references
    client = kcc_client.KccClient()
    output = None
    with progress_tracker.ProgressTracker(
        message='Applying {}'.format(resource_path),
        aborted_message='Apply Cancelled'):
      output = client.ApplyConfig(resource_path, resolve_refs)
    return output




# -*- coding: utf-8 -*- #
# Copyright 2016 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""List command for gcloud debug logpoints command group."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

import datetime

from googlecloudsdk.api_lib.debug import debug
from googlecloudsdk.calliope import arg_parsers
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.debug import flags
from googlecloudsdk.core import properties
from googlecloudsdk.core.util import times

DETAILED_HELP = {
    'brief':
        """\
        List the debug logpoints for a Cloud Debugger debug target (debuggee).
    """,
    'DESCRIPTION':
        """\
        *{command}* is used to display the debug logpoints for a Cloud Debugger
        debug target (debuggee). By default all active logpoints are returned.
        To obtain older, expired logoints, specify the --include-inactive
        option.
    """,
    'EXAMPLES':
        """\
        To list the active and recently completed debug logpoints of the debug
        target (debuggee), run:

          $ {command} --target=<debuggee_id>

        To list all (both active and inactive) logpoints of the debug target
        (debuggee), run:

          $ {command} --target=<debuggee_id> --include-inactive=unlimited

        To list logpoints only created by the current user (by default all users
        are returned) of the debug target (debuggee), run:

          $ {command} --target=<debuggee_id> --no-all-users
    """
}


class List(base.ListCommand):
  """List debug logpoints."""

  detailed_help = DETAILED_HELP

  @staticmethod
  def Args(parser):
    base.URI_FLAG.RemoveFromParser(parser)
    base.PAGE_SIZE_FLAG.RemoveFromParser(parser)
    flags.AddIdOptions(parser, 'logpoint', 'logpoints', 'listed')
    parser.add_argument(
        '--all-users', action='store_true', default=True,
        help="""\
            If false, display only logpoints created by the current user.
        """)
    parser.add_argument(
        '--include-inactive', default=300,
        type=arg_parsers.BoundedInt(lower_bound=0, unlimited=True),
        help="""\
            Include logpoints which failed or expired in the last
            INCLUDE_INACTIVE seconds. If the value is "unlimited", all failed
            or expired logpoints will be included.
        """)
    parser.display_info.AddFormat("""
          table(
            userEmail.if(all_users),
            location,
            condition,
            logLevel,
            logMessageFormat,
            id,
            full_status():label=STATUS)
            :(isFinalState:sort=1, createTime:sort=2)
    """)

  def Run(self, args):
    """Run the list command."""
    project_id = properties.VALUES.core.project.Get(required=True)
    debugger = debug.Debugger(project_id)
    debuggee = debugger.FindDebuggee(args.target)
    logpoints = debuggee.ListBreakpoints(
        args.location, resource_ids=args.ids, include_all_users=args.all_users,
        include_inactive=(args.include_inactive != 0),
        restrict_to_type=debugger.LOGPOINT_TYPE)

    # Filter any results more than include_inactive seconds old.
    # include_inactive may be None, which means we do not want to filter the
    # results.
    if args.include_inactive:
      cutoff_time = (times.Now(times.UTC) -
                     datetime.timedelta(seconds=args.include_inactive))
      logpoints = [lp for lp in logpoints if _ShouldInclude(lp, cutoff_time)]

    return logpoints


def _ShouldInclude(logpoint, cutoff_time):
  """Determines if a logpoint should be included in the output.

  Args:
    logpoint: a Breakpoint object describing a logpoint.
    cutoff_time: The oldest finalTime to include for completed logpoints.
  Returns:
    True if the logpoint should be included based on the criteria in args.
  """
  if not logpoint.isFinalState or not logpoint.finalTime:
    return True
  final_time = times.ParseDateTime(logpoint.finalTime, tzinfo=times.UTC)
  return final_time >= cutoff_time



# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""'Bare Metal Solution volumes "restore" command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.bms.bms_client import BmsClient
from googlecloudsdk.api_lib.util import waiter
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.bms import flags
from googlecloudsdk.core import log
from googlecloudsdk.core import resources


DETAILED_HELP = {
    'DESCRIPTION':
        """
          Restore a Bare Metal Solution volume to an existing snapshot.

          This call returns immediately, but the restore operation may take
          several minutes to complete. To check if the operation is complete,
          use the `describe` command for the volume.
        """,
    'EXAMPLES':
        """
          To restore a volume named ``my-volume'' in region
          ``us-central1'' to a snapshot named ``my-snapshot'', run:

          $ {command} my-volume --region=us-central1 --snapshot=my-snapshot
    """,
}


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Restore(base.UpdateCommand):
  """Restore a Bare Metal Solution volume to an existing snapshot."""

  @staticmethod
  def Args(parser):
    """Register flags for this command."""
    flags.AddVolumeArgToParser(parser, positional=True)
    parser.add_argument('--snapshot',
                        required=True,
                        help='Name of the snapshot to restore.')
    base.ASYNC_FLAG.AddToParser(parser)

  def Run(self, args):
    volume = args.CONCEPTS.volume.Parse()
    client = BmsClient()
    op_ref = client.RestoreVolumeSnapshot(volume, args.snapshot)

    if op_ref.done:
      log.RestoredResource(volume.Name(), kind='volume')
      return op_ref

    if args.async_:
      log.status.Print('Restore request issued for [{}]\nCheck operation '
                       '[{}] for status.'.format(volume.Name(), op_ref.name))
      return op_ref

    op_resource = resources.REGISTRY.ParseRelativeName(
        op_ref.name,
        collection='baremetalsolution.operations',
        api_version='v1')
    poller = waiter.CloudOperationPollerNoResources(
        client.operation_service)
    res = waiter.WaitFor(poller, op_resource,
                         'Waiting for operation [{}] to complete'.format(
                             op_ref.name))
    log.RestoredResource(volume.Name(), kind='volume')
    return res


Restore.detailed_help = DETAILED_HELP



# -*- coding: utf-8 -*- #
# Copyright 2021 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Code that's shared between multiple org firewall policies subcommands."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

import re
import sys

from googlecloudsdk.core import log

ORGANIZATION_PREFIX = 'organizations/'


def ResolveFirewallPolicyId(firewall_policy, short_name, organization_id):
  """Returns the firewall policy id that matches the short_name in the org.

  Args:
    firewall_policy: the organization firewall policy.
    short_name: the short name of the firewall policy to be resolved.
    organization_id: the organization ID which the firewall policy belongs to.

  Returns:
    Firewall policy resource ID.
  """

  response = firewall_policy.List(
      parent_id=organization_id, only_generate_request=False)
  fp_id = None
  for fp in response[0].items:
    if fp.displayName == short_name:
      fp_id = fp.name
      break
  if fp_id is None:
    log.error(
        'Invalid short name: {0}. No Security Policy with this short name exists.'
        .format(short_name))
    sys.exit()
  return fp_id


def GetFirewallPolicyId(firewall_policy_client,
                        firewall_policy,
                        organization=None):
  """Returns the firewall policy id that matches the short_name in the org.

  Args:
    firewall_policy_client: the organization firewall policy client.
    firewall_policy: the short name or ID of the firewall policy to be resolved.
    organization: the organization ID which the firewall policy belongs to.

  Returns:
    Firewall policy resource ID.
  """

  # If it is not numeric ID with length between 9 and 15, then do the lookup.
  if not re.match(r'\d{9,15}', firewall_policy):
    if organization is None:
      log.error(
          'Must set --organization=ORGANIZATION when short name [%s]'
          'is used.', firewall_policy)
      sys.exit()
    return ResolveFirewallPolicyId(firewall_policy_client, firewall_policy,
                                   ORGANIZATION_PREFIX + organization)
  return firewall_policy



# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for listing existing triggers."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.events import eventflow_operations
from googlecloudsdk.command_lib.kuberun import connection_context


@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
class List(base.ListCommand):
  """List available event source kinds."""

  detailed_help = {
      'DESCRIPTION':
          """
          {description}
          """,
      'EXAMPLES':
          """
          To list available event source kinds:

              $ {command}
          """,
  }

  @staticmethod
  def CommonArgs(parser):
    parser.display_info.AddFormat("""table(source_kind:label=SOURCE:sort=1)""")

  @staticmethod
  def Args(parser):
    List.CommonArgs(parser)

  def Run(self, args):
    conn_context = connection_context.EventsConnectionContext(args)

    with eventflow_operations.Connect(conn_context) as client:
      source_crds = client.ListSourceCustomResourceDefinitions()
      return [crd for crd in source_crds if crd.event_types]



# -*- coding: utf-8 -*- #
# Copyright 2020 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Wait for an execution to complete."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.workflows import workflows
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.workflows import flags
from googlecloudsdk.command_lib.workflows import hooks


@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
                    base.ReleaseTrack.GA)
class Wait(base.DescribeCommand):
  """Wait for an execution to complete."""

  detailed_help = {
      'DESCRIPTION':
          '{description}',
      'EXAMPLES':
          """\
          To wait for an execution with ID 'my-workflow-execution-ID' from a
          workflow named 'my-workflow' to finish, run:

            $ {command} my-workflow-execution-ID --workflow=my-workflow

          """,
  }

  @staticmethod
  def Args(parser):
    flags.AddExecutionResourceArg(parser, verb='to wait on')

  def Run(self, args):
    """Starts the wait on the completion of the execution."""
    hooks.print_default_location_warning(None, args, None)
    api_version = workflows.ReleaseTrackToApiVersion(self.ReleaseTrack())
    execution_ref = flags.ParseExecution(args)
    client = workflows.WorkflowExecutionClient(api_version)
    return client.WaitForExecution(execution_ref)
